<?php
/**
* The template for adding Featured Content Settings in Customizer
*
 * @package Decree Pro
*/

$wp_customize->add_section( 'decree_featured_content', array(
	'panel'    => 'decree_theme_options',
	'priority' => 400,
	'title'    => esc_html__( 'Featured Content', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_option]', array(
	'default'			=> $defaults['featured_content_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_option]', array(
	'choices'  	=> decree_section_visibility_options(),
	'label'    	=> esc_html__( 'Enable on', 'decree-pro' ),
	'section'  	=> 'decree_featured_content',
	'settings' 	=> 'decree_theme_options[featured_content_option]',
	'type'	  	=> 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_bg_image]', array(
	'default'			=> $defaults['featured_content_bg_image'],
	'sanitize_callback' => 'decree_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'decree_theme_options[featured_content_bg_image]', array(
	'active_callback' => 'decree_is_featured_content_active',
	'label'           => esc_html__( 'Background Image', 'decree-pro' ),
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_bg_image]',
) ) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_layout]', array(
	'default'			=> $defaults['featured_content_layout'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_layout]', array(
	'active_callback' => 'decree_is_featured_content_active',
	'choices'         => decree_featured_content_layout_options(),
	'label'           => esc_html__( 'Select Featured Content Layout', 'decree-pro' ),
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_layout]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_position]', array(
	'default'			=> $defaults['featured_content_position'],
	'sanitize_callback' => 'decree_sanitize_checkbox'
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_position]', array(
	'active_callback' => 'decree_is_featured_content_active',
	'label'           => esc_html__( 'Check to Move above Footer', 'decree-pro' ),
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_position]',
	'type'            => 'checkbox',
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_type]', array(
	'default'			=> $defaults['featured_content_type'],
	'sanitize_callback'	=> 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_type]', array(
	'active_callback' => 'decree_is_featured_content_active',
	'choices'         => decree_featured_content_types(),
	'label'           => esc_html__( 'Select Content Type', 'decree-pro' ),
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_headline]', array(
	'default'			=> $defaults['featured_content_headline'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_headline]' , array(
	'active_callback'	=> 'decree_is_featured_content_active',
	'description'	=> esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'    		=> esc_html__( 'Headline for Featured Content', 'decree-pro' ),
	'section'  		=> 'decree_featured_content',
	'settings' 		=> 'decree_theme_options[featured_content_headline]',
	'type'	   		=> 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[featured_content_subheadline]', array(
	'default'			=> $defaults['featured_content_subheadline'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_subheadline]' , array(
	'active_callback'	=> 'decree_is_featured_content_active',
	'description'	=> esc_html__( 'Leave field empty to remove', 'decree-pro' ),
	'label'    		=> esc_html__( 'Sub-headline for Featured Content', 'decree-pro' ),
	'section'  		=> 'decree_featured_content',
	'settings' 		=> 'decree_theme_options[featured_content_subheadline]',
	'type'	   		=> 'text',
	)
);

$wp_customize->add_setting( 'decree_theme_options[featured_content_number]', array(
	'default'			=> $defaults['featured_content_number'],
	'sanitize_callback'	=> 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_number]' , array(
		'active_callback' => 'decree_is_featured_page_post_category_image_content_active',
		'description'     => esc_html__( 'Save and refresh the page if No. of Featured Content is changed', 'decree-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 100px;',
			'min'   => 1,
			'step'  => 1,
		),
		'label'           => esc_html__( 'No of Featured Content', 'decree-pro' ),
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_number]',
		'type'            => 'number',
		'transport'       => 'postMessage'
	)
);

$wp_customize->add_setting( 'decree_theme_options[featured_content_show]', array(
	'default'			=> $defaults['featured_content_show'],
	'sanitize_callback'	=> 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[featured_content_show]', array(
	'active_callback' => 'decree_is_featured_page_post_category_image_content_active',
	'choices'         => decree_featured_content_show(),
	'label'           => esc_html__( 'Display Content', 'decree-pro' ),
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_show]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[featured_content_select_category]', array(
	'sanitize_callback' => 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_Customize_Dropdown_Categories_Control( $wp_customize, 'decree_theme_options[featured_content_select_category]', array(
	'active_callback' => 'decree_is_featured_category_content_active',
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[featured_content_select_category]',
	'section'         => 'decree_featured_content',
	'settings'        => 'decree_theme_options[featured_content_select_category]',
	'type'            => 'dropdown-categories',
) ) );


//loop for featured post content
for ( $i=1; $i <= $options['featured_content_number'] ; $i++ ) {
	$wp_customize->add_setting( 'decree_theme_options[featured_content_post_' . $i . ']', array(
					'sanitize_callback' => 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_featured_content_post_'. $i, array(
			'active_callback' => 'decree_is_featured_post_content_active',
			'input_attrs'     => array(
				'style' => 'width: 40px;'
			),
			'label'           => esc_html__( 'Featured Post', 'decree-pro' ) . ' ' . $i ,
			'section'         => 'decree_featured_content',
			'settings'        => 'decree_theme_options[featured_content_post_' . $i . ']',
			'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'decree_theme_options[featured_content_page_' . $i . ']', array(
			'sanitize_callback' => 'decree_sanitize_page',
	) );

	$wp_customize->add_control( 'decree_featured_content_page_' . $i . '', array(
		'active_callback' => 'decree_is_featured_page_content_active',
		'label'           => esc_html__( 'Featured Page', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_page_' . $i . ']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'decree_theme_options[featured_content_note_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new decree_Note_Control( $wp_customize, 'featured_content_note_'. $i, array(
		'active_callback' => 'decree_is_featured_image_content_active',
		'label'           => esc_html__( 'Featured Content #', 'decree-pro' ) .  $i,
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_note_' . $i . ']',
		'type'            => 'description',
		) ) );

	$wp_customize->add_setting( 'decree_theme_options[featured_content_image_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_content_image_'. $i , array(
		'active_callback' => 'decree_is_featured_image_content_active',
		'label'           => esc_html__( 'Image', 'decree-pro' ),
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_image_' . $i . ']',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[featured_content_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[featured_content_link_' . $i . ']', array(
		'active_callback' => 'decree_is_featured_image_content_active',
		'label'           => esc_html__( 'Link', 'decree-pro' ),
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[featured_content_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[featured_content_target_' . $i . ']', array(
		'active_callback' => 'decree_is_featured_image_content_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'decree_theme_options[featured_content_title_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[featured_content_title_' . $i . ']', array(
		'active_callback' => 'decree_is_featured_image_content_active',
		'label'           => esc_html__( 'Title', 'decree-pro' ),
		'section'         => 'decree_featured_content',
		'settings'        => 'decree_theme_options[featured_content_title_' . $i . ']',
		'type'            => 'text',
	) );

    $wp_customize->add_setting( 'decree_theme_options[featured_content_content_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[featured_content_content_' . $i . ']', array(
			'active_callback'	=> 'decree_is_featured_image_content_active',
			'label'		=> esc_html__( 'Content', 'decree-pro' ),
			'section'   => 'decree_featured_content',
			'settings'  => 'decree_theme_options[featured_content_content_' . $i . ']',
			'type'		=> 'textarea',
    ) );

	$wp_customize->add_setting( 'decree_theme_options[featured_content_button_text_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'decree_theme_options[featured_content_button_text_' . $i . ']', array(
			'active_callback'	=> 'decree_is_featured_image_content_active',
			'label'		=> esc_html__( 'Button Text', 'decree-pro' ),
			'section'   => 'decree_featured_content',
			'settings'  => 'decree_theme_options[featured_content_button_text_' . $i . ']',
			'type'		=> 'text',
    ) );
}
