<?php
/**
 * The template for adding Logo Slider Options in Customizer
 *
 * @package Decree Pro
 */

//Logo Slider
$wp_customize->add_section( 'decree_logo_slider', array(
	'panel' => 'decree_theme_options',
	'title' => esc_html__( 'Logo Slider', 'decree-pro' ),
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_option]', array(
	'default'			=> $defaults['logo_slider_option'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_option]', array(
	'choices'  => decree_section_visibility_options(),
	'label'    => esc_html__( 'Enable on', 'decree-pro' ),
	'section'  => 'decree_logo_slider',
	'settings' => 'decree_theme_options[logo_slider_option]',
	'type'     => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_bg_image]', array(
	'default'			=> $defaults['logo_slider_bg_image'],
	'sanitize_callback' => 'decree_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'decree_theme_options[logo_slider_bg_image]', array(
	'active_callback' => 'decree_is_logo_slider_active',
	'label'           => esc_html__( 'Background Image', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_bg_image]',
) ) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_transition_delay]', array(
	'default'			=> $defaults['logo_slider_transition_delay'],
	'sanitize_callback'	=> 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_transition_delay]' , array(
	'active_callback' => 'decree_is_logo_slider_active',
	'description'     => esc_html__( 'seconds(s)', 'decree-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 100px;',
		'min'   => 0,
		),
	'label'           => esc_html__( 'Transition Delay', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_transition_delay]',
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_transition_length]', array(
	'default'			=> $defaults['logo_slider_transition_length'],
	'sanitize_callback'	=> 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_transition_length]' , array(
		'active_callback' => 'decree_is_logo_slider_active',
		'description'     => esc_html__( 'seconds(s)', 'decree-pro' ),
		'input_attrs'     => array(
			'style' => 'width: 100px;',
			'min'   => 0,
		),
		'label'           => esc_html__( 'Transition Length', 'decree-pro' ),
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_transition_length]',
	)
);

$wp_customize->add_setting( 'decree_theme_options[logo_slider_type]', array(
	'default'			=> $defaults['logo_slider_type'],
	'sanitize_callback' => 'decree_sanitize_select',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_type]', array(
	'active_callback' => 'decree_is_logo_slider_active',
	'choices'         => decree_custom_section_types(),
	'label'           => esc_html__( 'Logo Slider Type', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_type]',
	'type'            => 'select',
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_title]', array(
	'default'			=> $defaults['logo_slider_title'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_title]' , array(
	'active_callback' => 'decree_is_demo_logo_slider_inactive',
	'label'           => esc_html__( 'Title', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_title]',
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_description]', array(
	'default'			=> $defaults['logo_slider_description'],
	'sanitize_callback'	=> 'wp_kses_post',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_description]' , array(
	'active_callback' => 'decree_is_demo_logo_slider_inactive',
	'label'           => esc_html__( 'Description', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_description]',
	'type'            => 'textarea'
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_number]', array(
	'default'			=> $defaults['logo_slider_number'],
	'sanitize_callback'	=> 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_number]' , array(
	'active_callback' => 'decree_is_demo_logo_slider_inactive',
	'description'     => esc_html__( 'Save and refresh the page if No. of Slides is changed', 'decree-pro' ),
	'input_attrs'     => array(
		'style' => 'width: 45px;',
		'min'   => 0,
	),
	'label'           => esc_html__( 'No of Items', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_number]',
	'type'            => 'number',
	)
);

$wp_customize->add_setting( 'decree_theme_options[logo_slider_visible_items]', array(
	'default'			=> $defaults['logo_slider_visible_items'],
	'sanitize_callback' => 'decree_sanitize_number_range',
) );

$wp_customize->add_control( 'decree_theme_options[logo_slider_visible_items]', array(
	'active_callback' => 'decree_is_demo_logo_slider_inactive',
	'input_attrs'     => array(
	'style'           => 'width: 45px;',
		'min'  => 1,
		'max'  => 5,
		'step' => 1,
	),
	'label'           => esc_html__( 'No of visible items', 'decree-pro' ),
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_visible_items]',
	'type'            => 'number',
) );

$wp_customize->add_setting( 'decree_theme_options[logo_slider_select_category]', array(
	'sanitize_callback'	=> 'decree_sanitize_category_list',
) );

$wp_customize->add_control( new decree_customize_dropdown_categories_control( $wp_customize, 'decree_logo_slider_select_category', array(
	'active_callback' => 'decree_is_logo_category_slider_active',
	'label'           => esc_html__( 'Select Categories', 'decree-pro' ),
	'name'            => 'decree_theme_options[logo_slider_select_category]',
	'section'         => 'decree_logo_slider',
	'settings'        => 'decree_theme_options[logo_slider_select_category]',
	'type'            => 'dropdown-categories',
) ) );

//loop for featured post sliders
for ( $i=1; $i <= $options['logo_slider_number'] ; $i++ ) {
	//post content
	$wp_customize->add_setting( 'decree_theme_options[logo_slider_post_' . $i . ']', array(
					'sanitize_callback'	=> 'decree_sanitize_page',
		)
	);

	$wp_customize->add_control( 'decree_logo_slider_post_'. $i, array(
		'active_callback' => 'decree_is_logo_post_slider_active',
		'input_attrs'     => array( 'style' => 'width: 100px;'),
		'label'           => esc_html__( 'Post', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_post_' . $i . ']',
		'type'            => 'text',
	) );

	//page content
	$wp_customize->add_setting( 'decree_theme_options[logo_slider_page_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_page',
	) );

	$wp_customize->add_control( 'decree_logo_slider_page_'. $i, array(
		'active_callback' => 'decree_is_logo_page_slider_active',
		'label'           => esc_html__( 'Page', 'decree-pro' ) . ' ' . $i ,
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_page_' . $i . ']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'decree_theme_options[logo_slider_note_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new decree_note_control( $wp_customize, 'logo_slider_note_'. $i, array(
		'active_callback' => 'decree_is_logo_image_slider_active',
		'label'           => esc_html__( 'Slide #', 'decree-pro' ) . $i,
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_note_' . $i . ']',
		'type'            => 'description',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[logo_slider_image_' . $i . ']', array(
			'sanitize_callback'	=> 'decree_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo_slider_image_'. $i , array(
		'active_callback' => 'decree_is_logo_image_slider_active',
		'label'           => esc_html__( 'Image', 'decree-pro' ),
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_image_' . $i . ']',
	) ) );

	$wp_customize->add_setting( 'decree_theme_options[logo_slider_title_' . $i . ']', array(
			'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'decree_theme_options[logo_slider_title_' . $i . ']', array(
		'active_callback' => 'decree_is_logo_image_slider_active',
		'label'           => esc_html__( 'Title/Image Alt', 'decree-pro' ),
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_title_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[logo_slider_link_' . $i . ']', array(
			'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'decree_theme_options[logo_slider_link_' . $i . ']', array(
		'active_callback' => 'decree_is_logo_image_slider_active',
		'label'           => esc_html__( 'Link', 'decree-pro' ),
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_link_' . $i . ']',
	) );

	$wp_customize->add_setting( 'decree_theme_options[logo_slider_target_' . $i . ']', array(
        	'sanitize_callback'	=> 'decree_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'decree_theme_options[logo_slider_target_' . $i . ']', array(
		'active_callback' => 'decree_is_logo_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'decree-pro' ),
		'section'         => 'decree_logo_slider',
		'settings'        => 'decree_theme_options[logo_slider_target_' . $i . ']',
		'type'            => 'checkbox',
    ) );
}
// Logo Slider End
