<?php
/**
 * Implement Default Theme/Customizer Options
 *
 * @package Decree Pro
 */

if ( ! function_exists( 'decree_get_default_theme_options' ) ) :
	/**
	 * Returns the default options for Decree.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_get_default_theme_options() {
		$theme_data = wp_get_theme();

		$options = array(
			'featured_content_bg_image'                     => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/bg-featured-content.jpg',
			'promotion_headline_bg_image'                   => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/bg-featured-content.jpg',
			'contact_page_bg_image'                         => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/bg-featured-content.jpg',
			'logo_slider_bg_image'                          => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/bg-featured-content.jpg',

			// Site Title an Tagline.
			'move_title_tagline'                            => 0,

			// Layout.
			'theme_layout'                                  => 'right-sidebar',
			'homepage_layout'                               => 'no-sidebar-full-width',
			'woocommerce_layout'                            => 'no-sidebar-full-width',
			'content_layout'                                => 'excerpt',
			'single_post_image_layout'                      => 'disabled',

			// Header Image.
			'enable_featured_header_image'                  => 'disabled',
			'featured_header_image_position'                => 'before-menu',
			'featured_image_size'                           => 'full',
			'featured_header_image_url'                     => '',
			'featured_header_image_alt'                     => '',
			'featured_header_image_base'                    => 0,

			// Navigation.
			'primary_menu_disable'                          => 0,
			'primary_search_disable'                        => 0,

			// Breadcrumb Options.
			'breadcrumb_option'                             => 0,
			'breadcrumb_on_homepage'                        => 0,
			'breadcrumb_seperator'                          => '&raquo;',

			// Comment Options.
			'comment_option'                                => 'use-wordpress-setting',
			'disable_notes'                                 => 0,
			'disable_website_field'                         => 0,

			// Custom CSS.
			'custom_css'                                    => '',

			// Scrollup Options.
			'disable_scrollup'                              => 0,

			// Header Right Sidebar Options.
			'disable_header_right_sidebar'                  => 0,
			'header_right_call_text'                        => esc_html__( 'Call Today', 'decree-pro' ),
			'header_right_call_number'                      => '000-000-0000',
			'header_right_button_text'                      => esc_html__( 'FREE Case Evaluation', 'decree-pro' ),
			'header_right_button_link'                      => '#',
			'header_right_button_link_target'               => 0,

			// Excerpt Options.
			'excerpt_length'                                => '45',
			'excerpt_more_text'                             => esc_html__( 'Read More ...', 'decree-pro' ),

			// Homepage / Frontpage Settings.
			'disable_homepage_content'                      => 0,
			'front_page_category'                           => '0',
			'front_page_title'                              => esc_html__( 'Recent Posts', 'decree-pro' ),
			'front_page_description'                        => current_user_can( 'edit_theme_options' ) ? sprintf(
				esc_html__( 'Here you can showcase the x number of recents posts which you can control from %1$sSettings - Readings%2$s', 'decree-pro' ),
				'<a target="_blank" href="' . esc_url( admin_url( 'options-reading.php' ) ) . '">',
				'</a>'
			) : '',

			// Pagination Options.
			'pagination_type'                               => 'default',

			// Promotion Headline Options.
			'promo_head_option'                             => 'homepage',
			'promo_head_type'                               => 'demo',
			'promo_head_show'                               => 'excerpt',
			'promo_head_title'                              => '',
			'promo_head_content'                            => '',
			'promo_head_button'                             => '',
			'promo_head_url'                                => '',
			'promo_head_target_1'                           => 1,
			'promo_head_button_2'                           => '',
			'promo_head_url_2'                              => '',
			'promo_head_target_2'                           => 1,
			'promo_head_background_image'                   => '',
			'promo_head_background_display_position'        => 'left',
			'promo_head_background_repeat'                  => 'repeat',
			'promo_head_background_attachment'              => 'scroll',

			// Search Options.
			'search_text'                                   => esc_html__( 'Search...', 'decree-pro' ),

			// Feed Redirect.
			'feed_redirect'                                 => '',

			// Fixed Header Top.
			'fixed_header_top'                              => 0,
			'disable_date'                                  => 0,
			'disable_social_icons'                          => 0,

			// Single Post Navigation.
			'disable_single_post_navigation'                => 0,

			// Font Family Options.
			'body_font'                                     => 'roboto',
			'title_font'                                    => 'roboto-slab',
			'tagline_font'                                  => 'roboto',
			'menu_font'                                     => 'roboto',
			'content_title_font'                            => 'roboto-slab',
			'content_font'                                  => 'roboto',
			'headings_font'                                 => 'roboto-slab',
			'reset_typography'                              => 0,

			// Footer Editor Options.
			'footer_content'                                => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. All Rights Reserved. %3$s', '1: Year, 2: Site Title with home URL, 3: Privacy Policy Link', 'decree-pro' ), '[the-year]', '[site-link]', '[privacy-policy-link]' ) . ' &#124; ' . esc_html( $theme_data->get( 'Name' ) ) . '&nbsp;' . esc_html__( 'by', 'decree-pro' ) . '&nbsp;<a target="_blank" href="' . esc_url( $theme_data->get( 'AuthorURI' ) ) . '">' . esc_html( $theme_data->get( 'Author' ) ) . '</a>',
			'reset_footer_content'                          => 0,

			// Update Notifier.
			'update_notifier'                               => 0,

			// Basic Color Options.
			'bg_color'                                      => '#ffffff',
			'text_color'                                    => '#1a1a1a',
			'link_color'                                    => '#b00f14',
			'link_hover_color'                              => '#1a1a1a',

			// Header Color Options.
			'header_textcolor'                              => '#1a1a1a',
			'header_bg_color'                               => '#ffffff',
			'site_title_hover_color'                        => '#b00f14',
			'tagline_color'                                 => '#1a1a1a',
			'header_right_title_color'                      => '#b00f14',
			'header_right_button_bg_color'                  => '#b00f14',
			'header_right_button_border_color'              => '#8f1014',
			'header_right_button_text_color'                => '#ffffff',
			'header_right_button_hover_bg_color'            => '#8f1014',
			'header_right_button_hover_border_color'        => '#b00f14',
			'header_right_button_hover_text_color'          => '#ffffff',

			// Content Color Options.
			'content_wrapper_bg_color'                      => '',
			'content_bg_color'                              => '',
			'content_title_color'                           => '#1a1a1a',
			'content_title_hover_color'                     => '#b00f14',
			'content_meta_color'                            => '#888888',
			'content_meta_hover_color'                      => '#b00f14',
			'sticky_post_title_bg_color'                    => '#b00f14',
			'sticky_post_title_text_color'                  => '#ffffff',

			// Sidebar Color Options.
			'sidebar_bg_color'                              => '',
			'sidebar_text_color'                            => '#1a1a1a',
			'sidebar_title_color'                           => '#1a1a1a',
			'sidebar_link_color'                            => '#b00f14',
			'sidebar_link_hover_color'                      => '#1a1a1a',
			'newsletter_form_bg_color'                      => '#1a1a1a',
			'newsletter_form_text_color'                    => '#e1e1e1',
			'newsletter_fields_bg_color'                    => '#fbfbfb',
			'newsletter_fields_text_color'                  => '#444444',
			'newsletter_fields_border_color'                => '#cccccc',
			'newsletter_fields_focus_bg_color'              => '#ffffff',
			'newsletter_fields_focus_text_color'            => '#1a1a1a',
			'newsletter_fields_focus_border_color'          => '#8f1014',
			'newsletter_submit_button_bg_color'             => '#b00f14',
			'newsletter_submit_button_border_color'         => '#8f1014',
			'newsletter_submit_button_text_color'           => '#ffffff',
			'newsletter_submit_button_hover_bg_color'       => '#f6f7f7',
			'newsletter_submit_button_hover_border_color'   => '#b00f14',
			'newsletter_submit_button_hover_text_color'     => '#ffffff',

			// Pagination Color Options.
			'pagination_bg_color'                           => '#ffffff',
			'pagination_border_color'                       => '#b00f14',
			'pagination_link_color'                         => '#b00f14',
			'pagination_hover_active_bg_color'              => '#b00f14',
			'pagination_hover_active_border_color'          => '#b00f14',
			'pagination_hover_active_link_color'            => '#ffffff',

			// Footer Color Options.
			'footer_bg_color'                               => '#ffffff',
			'footer_text_color'                             => '#1a1a1a',
			'footer_link_color'                             => '#1a1a1a',
			'footer_link_hover_color'                       => '#b00f14',
			'footer_sidebar_area_bg_color'                  => '#1a1a1a',
			'footer_widget_text_color'                      => '#dddddd',
			'footer_widget_title_color'                     => '#ffffff',
			'footer_widget_link_color'                      => '#ffffff',
			'footer_widget_link_hover_color'                => '#b00f14',

			// Promotion Headline Color Options.
			'promo_head_bg_color'                           => '#1a1a1a',
			'promo_head_text_color'                         => '#ffffff',
			'promo_head_title_color'                        => '#ffffff',
			'promo_head_title_hover_color'                  => '#b00f14',
			'promo_head_link_color'                         => '#b00f14',
			'promo_head_link_hover_color'                   => '#ffffff',
			'promo_head_button_bg_color'                    => '',
			'promo_head_button_border_color'                => '#ffffff',
			'promo_head_button_text_color'                  => '#ffffff',
			'promo_head_button_hover_bg_color'              => '#8f1014',
			'promo_head_button_hover_border_color'          => '#8f1014',
			'promo_head_button_hover_text_color'            => '#ffffff',

			// Scrollup Color Options.
			'scrollup_bg_color'                             => '#888888',
			'scrollup_text_color'                           => '#ffffff',
			'scrollup_hover_bg_color'                       => '#b00f14',
			'scrollup_hover_text_color'                     => '#ffffff',

			// Portfolio Color Options.
			'portfolio_bg_color'                            => '#ffffff',
			'portfolio_text_color'                          => '#1a1a1a',
			'portfolio_link_color'                          => '#b00f14',
			'portfolio_link_hover_color'                    => '#1a1a1a',
			'portfolio_headline_color'                      => '#1a1a1a',
			'portfolio_headline_hover_color'                => '#b00f14',
			'portfolio_subheadline_color'                   => '#1a1a1a',
			'portfolio_title_color'                         => '#1a1a1a',
			'portfolio_title_hover_color'                   => '#b00f14',
			'portfolio_meta_color'                          => '#1a1a1a',
			'portfolio_meta_hover_color'                    => '#b00f14',

			// Featured Content Color Options.
			'featured_content_bg_color'                     => '#1a1a1a',
			'featured_content_text_color'                   => '#ffffff',
			'featured_content_headline_color'               => '#ffffff',
			'featured_content_subheadline_color'            => '#ffffff',
			'featured_content_title_color'                  => '#ffffff',
			'featured_content_title_hover_color'            => '#b00f14',
			'featured_content_link_color'                   => '#b00f14',
			'featured_content_link_hover_color'             => '#ffffff',
			'featured_content_button_bg_color'              => '',
			'featured_content_button_border_color'          => '#ffffff',
			'featured_content_button_text_color'            => '#ffffff',
			'featured_content_button_hover_bg_color'        => '#8f1014',
			'featured_content_button_hover_border_color'    => '#8f1014',
			'featured_content_button_hover_text_color'      => '#ffffff',

			// Slider Color Options.
			'slider_bg_color'                               => '#1a1a1a',
			'slider_content_bg_color'                       => '',
			'slider_title_color'                            => '#ffffff',
			'slider_title_hover_color'                      => '#b00f14',
			'slider_text_color'                             => '#ffffff',
			'slider_link_color'                             => '#b00f14',
			'slider_link_hover_color'                       => '#ffffff',
			'slider_button_bg_color'                        => '#b00f14',
			'slider_button_border_color'                    => '#8f1014',
			'slider_button_link_color'                      => '#ffffff',
			'slider_button_hover_bg_color'                  => '#8f1014',
			'slider_button_hover_border_color'              => '#b00f14',
			'slider_button_hover_link_color'                => '#ffffff',

			// Primary Menu Color Options.
			'menu_bg_color'                                 => '#0b0b0b',
			'menu_color'                                    => '#ffffff',
			'hover_active_bg_color'                         => '',
			'hover_active_text_color'                       => '#d7060d',
			'sub_menu_bg_color'                             => '',
			'sub_menu_border_top_color'                     => '#d7060d',
			'sub_menu_text_color'                           => '#1a1a1a',
			'sub_menu_border_between_color'                 => '#d1d1d1',
			'sub_menu_hover_bg_color'                       => '',
			'sub_menu_hover_text_color'                     => '#d7060d',

			// Secondary Menu Color Options.
			'sec_menu_bg_color'                             => '#f6f7f7',
			'sec_menu_color'                                => '#1a1a1a',
			'sec_hover_active_bg_color'                     => '',
			'sec_hover_active_text_color'                   => '#d7060d',
			'sec_sub_menu_bg_color'                         => '#f6f7f7',
			'sec_sub_menu_border_top_color'                 => '#d7060d',
			'sec_sub_menu_text_color'                       => '#1a1a1a',
			'sec_sub_menu_border_between_color'             => '#d1d1d1',

			// Header Top Menu Color Options.
			'header_top_menu_bg_color'                      => '',
			'header_top_menu_color'                         => '#d7060d',
			'header_top_hover_active_bg_color'              => '',
			'header_top_hover_active_text_color'            => '#d7060d',
			'header_top_sub_menu_bg_color'                  => '#ffffff',
			'header_top_sub_menu_border_top_color'          => '#d7060d',
			'header_top_sub_menu_text_color'                => '#1a1a1a',
			'header_top_sub_menu_border_between_color'      => '#d1d1d1',
			'header_top_sub_menu_hover_bg_color'            => '',
			'header_top_sub_menu_hover_text_color'          => '#d7060d',

			// Header Right Color Options.
			'header_right_menu_bg_color'                    => '',
			'header_right_menu_color'                       => '#1a1a1a',
			'header_right_hover_active_bg_color'            => '',
			'header_right_hover_active_text_color'          => '#d7060d',
			'header_right_sub_menu_bg_color'                => '#ffffff',
			'header_right_sub_menu_border_top_color'        => '#d7060d',
			'header_right_sub_menu_text_color'              => '#1a1a1a',
			'header_right_sub_menu_border_between_color'    => '#d1d1d1',
			'header_right_sub_menu_hover_bg_color'          => '',
			'header_right_sub_menu_hover_text_color'        => '#d7060d',

			// Footer Menu Color Options.
			'footer_menu_bg_color'                          => '',
			'footer_menu_color'                             => '#1a1a1a',
			'footer_hover_active_bg_color'                  => '',
			'footer_hover_active_text_color'                => '#b00f14',

			// Hero Content Color Options.
			'hero_bg_color'                                 => '#ffffff',
			'hero_text_color'                               => '#1a1a1a',
			'hero_content_bg_color'                         => '#f7f7f7',
			'hero_title_color'                              => '#1a1a1a',
			'hero_title_hover_color'                        => '#b00f14',
			'hero_link_color'                               => '#b00f14',
			'hero_link_hover_color'                         => '#1a1a1a',
			'hero_button_bg_color'                          => '',
			'hero_button_border_color'                      => '#b00f14',
			'hero_button_text_color'                        => '#b00f14',
			'hero_button_hover_bg_color'                    => '#8f1014',
			'hero_button_hover_border_color'                => '#8f1014',
			'hero_button_hover_text_color'                  => '#ffffff',

			// Testimonial Color Options.
			'testimonial_bg_color'                          => '#ffffff',
			'testimonial_headline_color'                    => '#1a1a1a',
			'testimonial_subheadline_color'                 => '#1a1a1a',
			'testimonial_text_color'                        => '#1a1a1a',
			'testimonial_name_color'                        => '#1a1a1a',
			'testimonial_position_color'                    => '#888888',

			// Contact Page Color Options.
			'contact_page_bg_color'                         => '#1a1a1a',
			'contact_page_text_color'                       => '#ffffff',
			'contact_page_link_color'                       => '#b00f14',
			'contact_page_link_hover_color'                 => '#ffffff',
			'contact_page_title_color'                      => '#ffffff',
			'contact_page_title_hover_color'                => '#b00f14',
			'contact_page_form_fields_bg_color'             => '#fbfbfb',
			'contact_page_form_fields_border_color'         => '#cccccc',
			'contact_page_form_fields_text_color'           => '#444444',
			'contact_page_form_fields_focus_bg_color'       => '#ffffff',
			'contact_page_form_fields_focus_border_color'   => '#b00f14',
			'contact_page_form_fields_focus_text_color'     => '#1a1a1a',
			'contact_page_submit_button_bg_color'           => '#b00f14',
			'contact_page_submit_button_border_color'       => '#8f1014',
			'contact_page_submit_button_text_color'         => '#ffffff',
			'contact_page_submit_button_hover_bg_color'     => '#8f1014',
			'contact_page_submit_button_hover_border_color' => '#b00f14',
			'contact_page_submit_button_hover_text_color'   => '#ffffff',

			'contact_info_bg_color'                         => '#ffffff',
			'contact_info_border_color'                     => '#f7f7f7',
			'contact_info_text_color'                       => '#1a1a1a',
			'contact_info_link_color'                       => '#1a1a1a',
			'contact_info_link_hover_color'                 => '#b00f14',

			// Portfolio Options.
			'portfolio_option'                              => 'homepage',
			'portfolio_type'                                => 'demo',
			'portfolio_layout'                              => 'four-columns',
			'portfolio_headline'                            => '',
			'portfolio_subheadline'                         => '',
			'portfolio_number'                              => '4',
			'portfolio_select_category'                     => '0',
			'portfolio_show'                                => 'hide-content',
			'portfolio_hide_category'                       => 0,
			'portfolio_hide_tags'                           => 1,
			'portfolio_hide_author'                         => 1,
			'portfolio_hide_date'                           => 0,

			// Hero Content Options.
			'hero_content_option'                           => 'homepage',
			'hero_content_type'                             => 'demo',
			'hero_content_number'                           => '1',
			'hero_content_enable_title'                     => 1,
			'hero_content_show'                             => 'excerpt',
			'hero_content_select_category'                  => '0',
			'hero_content_background_image'                 => '',
			'hero_content_background_display_position'      => 'left',
			'hero_content_background_repeat'                => 'repeat',
			'hero_content_background_attachment'            => 'scroll',
			'disable_read_more'                             => 0,

			// Featured Content Options.
			'featured_content_option'                       => 'homepage',
			'featured_content_layout'                       => 'four-columns',
			'featured_content_position'                     => 0,
			'featured_content_headline'                     => esc_html__( 'Featured Content', 'decree-pro' ),
			'featured_content_subheadline'                  => '',
			'featured_content_type'                         => 'demo',
			'featured_content_number'                       => '4',
			'featured_content_select_category'              => '0',
			'featured_content_show'                         => 'excerpt',

			// News Ticker Options.
			'news_ticker_option'                            => 'homepage',
			'news_ticker_position'                          => 'above-content',
			'news_ticker_type'                              => 'demo',
			'news_ticker_label'                             => '',
			'news_ticker_transition_effect'                 => 'flipVert',
			'news_ticker_number'                            => '4',
			'news_ticker_select_category'                   => '0',

			// Featured Slider Options.
			'featured_slider_option'                        => 'homepage',
			'featured_slider_image_loader'                  => 'true',
			'featured_slider_transition_effect'             => 'fadeout',
			'featured_slider_transition_delay'              => '4',
			'featured_slider_transition_length'             => '1',
			'featured_slider_type'                          => 'demo',
			'featured_slider_number'                        => '4',
			'featured_slider_select_category'               => '0',
			'exclude_slider_post'                           => 0,

			// Testimonail Options.
			'testimonial_option'                            => 'homepage',
			'testimonial_layout'                            => 'one-column',
			'testimonial_position'                          => 0,
			'testimonial_slider'                            => 1,
			'testimonial_headline'                          => '',
			'testimonial_subheadline'                       => '',
			'testimonial_type'                              => 'demo',
			'testimonial_number'                            => '4',
			'testimonial_enable_title'                      => 1,
			'testimonial_show'                              => 'full-content',
			'testimonial_select_category'                   => '0',
			'testimonial_background_image'                  => '',
			'testimonial_background_display_position'       => 'left',
			'testimonial_background_repeat'                 => 'repeat',
			'testimonial_background_attachment'             => 'scroll',

			// Logo Slider.
			'logo_slider_option'                            => 'homepage',
			'logo_slider_type'                              => 'demo',
			'logo_slider_visible_items'                     => '4',
			'logo_slider_transition_delay'                  => '4',
			'logo_slider_transition_length'                 => '1',
			'logo_slider_title'                             => '',
			'logo_slider_description'                       => '',
			'logo_slider_number'                            => '5',
			'logo_slider_select_category'                   => '0',
			'logo_slider_background_image'                  => '',
			'logo_slider_background_display_position'       => 'left',
			'logo_slider_background_repeat'                 => 'repeat',
			'logo_slider_background_attachment'             => 'scroll',

			// Team Options.
			'team_option'                                   => 'homepage',
			'team_layout'                                   => 'four-columns',
			'team_position'                                 => 0,
			'team_headline'                                 => esc_html__( 'Our Attorneys', 'decree-pro' ),
			'team_subheadline'                              => esc_html__( 'This is Team Section and you can edit this from Appearnce - Customize - Theme - Team Options. Details information of Team Options can be found in our theme instructions page', 'decree-pro' ),
			'team_type'                                     => 'demo',
			'team_number'                                   => '4',
			'team_enable_title'                             => 1,
			'team_show'                                     => 'hide-content',
			'team_select_category'                          => '0',
			'team_background_image'                         => '',
			'team_background_display_position'              => 'left',
			'team_background_repeat'                        => 'repeat',
			'team_background_attachment'                    => 'scroll',

			// Contact Form Options.
			'contact_form_option'                           => 'disabled',
			'contact_form_type'                             => 'page',
			'contact_form_enable_title'                     => 1,

			// Contact Info Options.
			'contact_info_option'                           => 'homepage',
			'contact_info_heading'                          => esc_html__( 'Contact Information', 'decree-pro' ),
			'contact_info_social_heading'                   => esc_html__( 'Stay Connected', 'decree-pro' ),
			'contact_info_enable_social'                    => 1,
			'contact_info_phone'                            => '000.000.0000',
			'contact_info_fax'                              => '000.000.0000',
			'contact_info_email'                            => 'something@yourdomain.com',
			'contact_info_bg'                               => 'image',
			'contact_info_image'                            => trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/map.jpg',
			'contact_info_address'                          => '2570 Bradford Square NE
Atlanta 30345, USA',
			'contact_info_format_address'                   => 1,
			'contact_info_link_text'                        => esc_html__( 'View larger map', 'decree-pro' ),
			'contact_info_link'                             => '#',
			'contact_info_target'                           => 1,

			// Social Links.
			'social_icon_size'                              => '20',
			'custom_social_icons'                           => '1',

			// WooCommerce Options.
			'disable_product_gallery_zoom'                  => 0,
			'disable_product_gallery_lightbox'              => 0,
			'disable_product_gallery_slider'                => 0,

			// Reset all settings.
			'reset_all_settings'                            => 0,
		);

		return apply_filters( 'decree_default_theme_options', $options );
	}
endif;

/**
 * Returns an array of layout options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_layouts() {
	$layout_options = array(
		'left-sidebar'                => esc_html__( 'Primary Sidebar, Content', 'decree-pro' ),
		'right-sidebar'               => esc_html__( 'Content, Primary Sidebar', 'decree-pro' ),
		'no-sidebar'                  => esc_html__( 'No Sidebar ( Content Width )', 'decree-pro' ),
		'no-sidebar-one-column'       => esc_html__( 'No Sidebar ( One Column )', 'decree-pro' ),
		'no-sidebar-full-width'       => esc_html__( 'No Sidebar ( Full Width )', 'decree-pro' ),
	);
	return apply_filters( 'decree_layouts', $layout_options );
}


/**
 * Returns an array of content layout options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_get_archive_content_layout() {
	$layout_options = array(
		'excerpt'      => esc_html__( 'Excerpt', 'decree-pro' ),
		'full-content' => esc_html__( 'Show Full Content (No Featured Image)', 'decree-pro' ),
	);

	return apply_filters( 'decree_get_archive_content_layout', $layout_options );
}


/**
 * Returns an array of feature header enable options
 *
 * @since Decree Pro 1.0
 */
function decree_enable_featured_header_image_options() {
	$options = array(
		'homepage'               => esc_html__( 'Homepage / Frontpage', 'decree-pro' ),
		'exclude-home'           => esc_html__( 'Excluding Homepage', 'decree-pro' ),
		'exclude-home-page-post' => esc_html__( 'Excluding Homepage, Page/Post Featured Image', 'decree-pro' ),
		'entire-site'            => esc_html__( 'Entire Site', 'decree-pro' ),
		'entire-site-page-post'  => esc_html__( 'Entire Site, Page/Post Featured Image', 'decree-pro' ),
		'pages-posts'            => esc_html__( 'Pages and Posts', 'decree-pro' ),
		'disabled'               => esc_html__( 'Disabled', 'decree-pro' ),
	);

	return apply_filters( 'decree_enable_featured_header_image_options', $options );
}


/**
 * Returns an array of feature header image positions
 *
 * @since Decree Pro 1.0
 */
function decree_featured_header_image_position_options() {
	$options = array(
		'before-menu'   => esc_html__( 'Before Menu', 'decree-pro' ),
		'after-menu'    => esc_html__( 'After Menu', 'decree-pro' ),
		'before-header' => esc_html__( 'Before Header', 'decree-pro' ),
		'after-slider'  => esc_html__( 'After Slider', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_header_image_position_options', $options );
}


/**
 * Returns an array of header highlight content types registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_portfolio_types() {
	$options = array(
		'demo'              => esc_html__( 'Demo', 'decree-pro' ),
		'post'              => esc_html__( 'Post', 'decree-pro' ),
		'jetpack-portfolio' => esc_html__( 'Custom Post Type', 'decree-pro' ),
		'page'              => esc_html__( 'Page', 'decree-pro' ),
		'category'          => esc_html__( 'Category', 'decree-pro' ),
		'image'             => esc_html__( 'Custom', 'decree-pro' ),
		'embed'             => esc_html__( 'Embed', 'decree-pro' ),
	);

	return apply_filters( 'decree_portfolio_types', $options );
}


/**
 * Returns an array of content and slider layout options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_section_visibility_options() {
	$options = array(
		'homepage'    => esc_html__( 'Homepage / Frontpage', 'decree-pro' ),
		'entire-site' => esc_html__( 'Entire Site', 'decree-pro' ),
		'disabled'    => esc_html__( 'Disabled', 'decree-pro' ),
	);

	return apply_filters( 'decree_section_visibility_options', $options );
}

/**
 * Returns an array of section types
 *
 * @since Decree Pro 1.0
 */
function decree_custom_section_types() {
	$options = array(
		'demo'     => esc_html__( 'Demo', 'decree-pro' ),
		'post'     => esc_html__( 'Post', 'decree-pro' ),
		'page'     => esc_html__( 'Page', 'decree-pro' ),
		'category' => esc_html__( 'Category', 'decree-pro' ),
		'image'    => esc_html__( 'Custom', 'decree-pro' ),
	);

	return apply_filters( 'decree_custom_section_types', $options );
}


/**
 * Returns an array of testimonial types registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_testimonial_types() {
	$options = array(
		'demo'                => esc_html__( 'Demo', 'decree-pro' ),
		'post'                => esc_html__( 'Post', 'decree-pro' ),
		'jetpack-testimonial' => esc_html__( 'Custom Post Type', 'decree-pro' ),
		'page'                => esc_html__( 'Page', 'decree-pro' ),
		'category'            => esc_html__( 'Category', 'decree-pro' ),
		'image'               => esc_html__( 'Custom', 'decree-pro' ),
	);

	return apply_filters( 'decree_testimonial_types', $options );
}


/**
 * Returns an array of news ticker types registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_news_ticker_types() {
	$options = array(
		'demo'     => esc_html__( 'Demo', 'decree-pro' ),
		'post'     => esc_html__( 'Post', 'decree-pro' ),
		'page'     => esc_html__( 'Page', 'decree-pro' ),
		'category' => esc_html__( 'Category', 'decree-pro' ),
		'custom'   => esc_html__( 'Custom', 'decree-pro' ),
	);

	return apply_filters( 'decree_news_ticker_types', $options );
}


/**
 * Returns an array of news ticker positions registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_news_ticker_positions() {
	$options = array(
		'below-menu'    => esc_html__( 'Below Menu', 'decree-pro' ),
		'above-content' => esc_html__( 'Above Content', 'decree-pro' ),
	);

	return apply_filters( 'decree_news_ticker_positions', $options );
}


/**
 * Returns an array of feature content types registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_featured_content_types() {
	$options = array(
		'demo'     => esc_html__( 'Demo', 'decree-pro' ),
		'post'     => esc_html__( 'Post', 'decree-pro' ),
		'page'     => esc_html__( 'Page', 'decree-pro' ),
		'category' => esc_html__( 'Category', 'decree-pro' ),
		'image'    => esc_html__( 'Custom', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_content_types', $options );
}


/**
 * Returns an array of featured content options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_featured_content_layout_options() {
	$options = array(
		'two-columns'   => esc_html__( '2 columns', 'decree-pro' ),
		'three-columns' => esc_html__( '3 columns', 'decree-pro' ),
		'four-columns'  => esc_html__( '4 columns', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_content_layout_options', $options );
}


/**
 * Returns an array of featured content show registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_featured_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'decree-pro' ),
		'full-content' => esc_html__( 'Show Full Content', 'decree-pro' ),
		'hide-content' => esc_html__( 'Hide Content', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_content_show', $options );
}


/**
 * Returns an array of testimonial content show registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_testimonial_content_show() {
	$options = array(
		'excerpt'      => esc_html__( 'Show Excerpt', 'decree-pro' ),
		'full-content' => esc_html__( 'Show Full Content', 'decree-pro' ),
	);

	return apply_filters( 'decree_testimonial_content_show', $options );
}


/**
 * Returns an array of testimonial layout options registered.
 *
 * @since Decree Pro 1.0
 */
function decree_testimonial_layout_options() {
	$options = array(
		'one-column'  => esc_html__( '1 column', 'decree-pro' ),
		'two-columns' => esc_html__( '2 columns', 'decree-pro' ),
	);

	return apply_filters( 'decree_testimonial_layout_options', $options );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Decree Pro 1.0
 */
function decree_featured_slider_transition_effects() {
	$options = array(
		'fade'       => esc_html__( 'Fade', 'decree-pro' ),
		'fadeout'    => esc_html__( 'Fade Out', 'decree-pro' ),
		'none'       => esc_html__( 'None', 'decree-pro' ),
		'scrollHorz' => esc_html__( 'Scroll Horizontal', 'decree-pro' ),
		'scrollVert' => esc_html__( 'Scroll Vertical', 'decree-pro' ),
		'flipHorz'   => esc_html__( 'Flip Horizontal', 'decree-pro' ),
		'flipVert'   => esc_html__( 'Flip Vertical', 'decree-pro' ),
		'tileSlide'  => esc_html__( 'Tile Slide', 'decree-pro' ),
		'tileBlind'  => esc_html__( 'Tile Blind', 'decree-pro' ),
		'shuffle'    => esc_html__( 'Shuffle', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_slider_transition_effects', $options );
}

/**
 * Returns an array of featured slider image loader options
 *
 * @since Decree Pro 1.0
 */
function decree_featured_slider_image_loader() {
	$options = array(
		'true'  => esc_html__( 'True', 'decree-pro' ),
		'wait'  => esc_html__( 'Wait', 'decree-pro' ),
		'false' => esc_html__( 'False', 'decree-pro' ),
	);

	return apply_filters( 'decree_featured_slider_image_loader', $options );
}


/**
 * Returns an array of pagination types registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_get_pagination_types() {
	$options = array(
		'default'         => esc_html__( 'Default(Older Posts/Newer Posts)', 'decree-pro' ),
		'numeric'         => esc_html__( 'Numeric', 'decree-pro' ),
		'infinite-scroll' => esc_html__( 'Infinite Scroll', 'decree-pro' ),
	);

	return apply_filters( 'decree_get_pagination_types', $options );
}


/**
 * Returns an array of content featured image size.
 *
 * @since Decree Pro 1.0
 */
function decree_image_sizes_options() {
	$options['disabled']             = esc_html__( 'Disabled', 'decree-pro' );
	$options['decree-featured']      = esc_html__( 'Featured', 'decree-pro' );
	$options['decree-featured-full'] = esc_html__( 'Featured Full Width', 'decree-pro' );
	$options['full']                 = esc_html__( 'Original', 'decree-pro' );

	return apply_filters( 'decree_image_sizes_options', $options );
}


/**
 * Returns an array of comment options for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_comment_options() {
	$options = array(
		'use-wordpress-setting' => esc_html__( 'Use WordPress Setting', 'decree-pro' ),
		'disable-in-pages'      => esc_html__( 'Disable in Pages', 'decree-pro' ),
		'disable-completely'    => esc_html__( 'Disable Completely', 'decree-pro' ),
	);

	return apply_filters( 'decree_comment_options', $options );
}

if ( ! function_exists( 'decree_avaliable_fonts' ) ) :
/**
 * Returns an array of avaliable fonts registered for Decree.
 *
 * @since Decree Pro 1.0
 */
	function decree_avaliable_fonts() {
		$options = array(
			'arial-black' => array(
				'value' => 'arial-black',
				'label' => '"Arial Black", Gadget, sans-serif',
			),
			'allan' => array(
				'value' => 'allan',
				'label' => '"Allan", sans-serif',
			),
			'allerta' => array(
				'value' => 'allerta',
				'label' => '"Allerta", sans-serif',
			),
			'amaranth' => array(
				'value' => 'amaranth',
				'label' => '"Amaranth", sans-serif',
			),
			'arial' => array(
				'value' => 'arial',
				'label' => 'Arial, Helvetica, sans-serif',
			),
			'bitter' => array(
				'value' => 'bitter',
				'label' => '"Bitter", sans-serif',
			),
			'cabin' => array(
				'value' => 'cabin',
				'label' => '"Cabin", sans-serif',
			),
			'cantarell' => array(
				'value' => 'cantarell',
				'label' => '"Cantarell", sans-serif',
			),
			'century-gothic' => array(
				'value' => 'century-gothic',
				'label' => '"Century Gothic", sans-serif',
			),
			'courier-new' => array(
				'value' => 'courier-new',
				'label' => '"Courier New", Courier, monospace',
			),
			'crimson-text' => array(
				'value' => 'crimson-text',
				'label' => '"Crimson Text", sans-serif',
			),
			'cuprum' => array(
				'value' => 'cuprum',
				'label' => '"Cuprum", sans-serif',
			),
			'dancing-script' => array(
				'value' => 'dancing-script',
				'label' => '"Dancing Script", sans-serif',
			),
			'droid-sans' => array(
				'value' => 'droid-sans',
				'label' => '"Droid Sans", sans-serif',
			),
			'droid-serif' => array(
				'value' => 'droid-serif',
				'label' => '"Droid Serif", sans-serif',
			),
			'exo' => array(
				'value' => 'exo',
				'label' => '"Exo", sans-serif',
			),
			'exo-2' => array(
				'value' => 'exo-2',
				'label' => '"Exo 2", sans-serif',
			),
			'georgia' => array(
				'value' => 'georgia',
				'label' => 'Georgia, "Times New Roman", Times, serif',
			),
			'helvetica' => array(
				'value' => 'helvetica',
				'label' => 'Helvetica, "Helvetica Neue", Arial, sans-serif',
			),
			'helvetica-neue' => array(
				'value' => 'helvetica-neue',
				'label' => '"Helvetica Neue",Helvetica,Arial,sans-serif',
			),
			'istok-web' => array(
				'value' => 'istok-web',
				'label' => '"Istok Web", sans-serif',
			),
			'impact' => array(
				'value' => 'impact',
				'label' => 'Impact, Charcoal, sans-serif',
			),
			'josefin-sans' => array(
				'value' => 'josefin-sans',
				'label' => '"Josefin Sans", sans-serif',
			),
			'lato' => array(
				'value' => 'lato',
				'label' => '"Lato", sans-serif',
			),
			'libre-baskerville' => array(
				'value' => 'libre-baskerville',
				'label' => '"Libre Baskerville",serif',
			),
			'lucida-sans-unicode' => array(
				'value' => 'lucida-sans-unicode',
				'label' => '"Ludica Sans Unicode", "Ludica Grande", sans-serif',
			),
			'lucida-grande' => array(
				'value' => 'lucida-grande',
				'label' => '"Ludica Grande", "Ludica Sans Unicode", sans-serif',
			),
			'lobster' => array(
				'value' => 'lobster',
				'label' => '"Lobster", sans-serif',
			),
			'lora' => array(
				'value' => 'lora',
				'label' => '"Lora", serif',
			),
			'monaco' => array(
				'value' => 'monaco',
				'label' => 'Monaco, Consolas, "Ludica Console", monospace, sans-serif',
			),
			'merriweather' => array(
				'value' => 'merriweather',
				'label' => '"Merriweather", sans-serif',
			),
			'montserrat' => array(
				'value' => 'montserrat',
				'label' => '"Montserrat", sans-serif',
			),
			'nobile' => array(
				'value' => 'nobile',
				'label' => '"Nobile", sans-serif',
			),
			'noto-serif' => array(
				'value' => 'noto-serif',
				'label' => '"Noto Serif", serif',
			),
			'neuton' => array(
				'value' => 'neuton',
				'label' => '"Neuton", serif',
			),
			'open-sans' => array(
				'value' => 'open-sans',
				'label' => '"Open Sans", sans-serif',
			),
			'oswald' => array(
				'value' => 'oswald',
				'label' => '"Oswald", sans-serif',
			),
			'palatino' => array(
				'value' => 'palatino',
				'label' => 'Palatino, "Palatino Linotype", "Book Antiqua", serif',
			),
			'patua-one' => array(
				'value' => 'patua-one',
				'label' => '"Patua One", sans-serif',
			),
			'playfair-display' => array(
				'value' => 'playfair-display',
				'label' => '"Playfair Display", sans-serif',
			),
			'pt-sans' => array(
				'value' => 'pt-sans',
				'label' => '"PT Sans", sans-serif',
			),
			'pt-serif' => array(
				'value' => 'pt-serif',
				'label' => '"PT Serif", serif',
			),
			'quattrocento' => array(
				'value' => 'quattrocento',
				'label' => '"Quattrocento", serif',
			),
			'quattrocento-sans' => array(
				'value' => 'quattrocento-sans',
				'label' => '"Quattrocento Sans", sans-serif',
			),
			'roboto' => array(
				'value' => 'roboto',
				'label' => '"Roboto", sans-serif',
			),
			'roboto-slab' => array(
				'value' => 'roboto-slab',
				'label' => '"Roboto Slab", serif',
			),
			'sans-serif' => array(
				'value' => 'sans-serif',
				'label' => 'Sans Serif, Arial',
			),
			'source-sans-pro' => array(
				'value' => 'source-sans-pro',
				'label' => '"Source Sans Pro", sans-serif',
			),
			'tahoma' => array(
				'value' => 'tahoma',
				'label' => 'Tahoma, Geneva, sans-serif',
			),
			'trebuchet-ms' => array(
				'value' => 'trebuchet-ms',
				'label' => '"Trebuchet MS", "Helvetica", sans-serif',
			),
			'times-new-roman' => array(
				'value' => 'times-new-roman',
				'label' => '"Times New Roman", Times, serif',
			),
			'ubuntu' => array(
				'value' => 'ubuntu',
				'label' => '"Ubuntu", sans-serif',
			),
			'varela' => array(
				'value' => 'varela',
				'label' => '"Varela", sans-serif',
			),
			'verdana' => array(
				'value' => 'verdana',
				'label' => 'Verdana, Geneva, sans-serif',
			),
			'yanone-kaffeesatz' => array(
				'value' => 'yanone-kaffeesatz',
				'label' => '"Yanone Kaffeesatz", sans-serif',
			),
		);

		return apply_filters( 'decree_avaliable_fonts', $options );
	}
endif;


/**
 * Returns list of social icons currently supported
 *
 * @since Decree Pro 1.0
 */
function decree_get_social_icons_list() {
	$options = array(
		'facebook_link'		=> array(
			'fa_class' 	=> 'facebook',
			'label' 			=> esc_html__( 'Facebook', 'decree-pro' ),
		),
		'twitter_link'		=> array(
			'fa_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'decree-pro' ),
		),
		'googleplus_link'	=> array(
			'fa_class' 	=> 'google-plus',
			'label' 			=> esc_html__( 'Googleplus', 'decree-pro' ),
		),
		'email_link'		=> array(
			'fa_class' 	=> 'envelope',
			'label' 			=> esc_html__( 'Email', 'decree-pro' ),
		),
		'feed_link'			=> array(
			'fa_class' 	=> 'feed',
			'label' 			=> esc_html__( 'Feed', 'decree-pro' ),
		),
		'wordpress_link'	=> array(
			'fa_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'decree-pro' ),
		),
		'github_link'		=> array(
			'fa_class' 	=> 'github',
			'label' 			=> esc_html__( 'GitHub', 'decree-pro' ),
		),
		'linkedin_link'		=> array(
			'fa_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'decree-pro' ),
		),
		'pinterest_link'	=> array(
			'fa_class' 	=> 'pinterest',
			'label' 			=> esc_html__( 'Pinterest', 'decree-pro' ),
		),
		'flickr_link'		=> array(
			'fa_class' 	=> 'flickr',
			'label' 			=> esc_html__( 'Flickr', 'decree-pro' ),
		),
		'vimeo_link'		=> array(
			'fa_class' 	=> 'vimeo',
			'label' 			=> esc_html__( 'Vimeo', 'decree-pro' ),
		),
		'youtube_link'		=> array(
			'fa_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'decree-pro' ),
		),
		'tumblr_link'		=> array(
			'fa_class' 	=> 'tumblr',
			'label' 			=> esc_html__( 'Tumblr', 'decree-pro' ),
		),
		'instagram_link'	=> array(
			'fa_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'decree-pro' ),
		),
		'vkontakte_link'	=> array(
			'fa_class' 	=> 'vk',
			'label' 			=> esc_html__( 'VKontakte', 'decree-pro' ),
		),
		'codepen_link'		=> array(
			'fa_class' 	=> 'codepen',
			'label' 			=> esc_html__( 'CodePen', 'decree-pro' ),
		),
		'xing_link'			=> array(
			'fa_class' 	=> 'xing',
			'label' 			=> esc_html__( 'Xing', 'decree-pro' ),
		),
		'dribbble_link'		=> array(
			'fa_class' 	=> 'dribbble',
			'label' 			=> esc_html__( 'Dribbble', 'decree-pro' ),
		),
		'skype_link'		=> array(
			'fa_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'decree-pro' ),
		),
		'digg_link'			=> array(
			'fa_class' 	=> 'digg',
			'label' 			=> esc_html__( 'Digg', 'decree-pro' ),
		),
		'reddit_link'		=> array(
			'fa_class' 	=> 'reddit',
			'label' 			=> esc_html__( 'Reddit', 'decree-pro' ),
		),
		'stumbleupon_link'	=> array(
			'fa_class' 	=> 'stumbleupon',
			'label' 			=> esc_html__( 'Stumbleupon', 'decree-pro' ),
		),
		'pocket_link'		=> array(
			'fa_class' 	=> 'get-pocket',
			'label' 			=> esc_html__( 'Pocket', 'decree-pro' ),
		),
		'dropbox_link'		=> array(
			'fa_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'decree-pro' ),
		),
		'spotify_link'		=> array(
			'fa_class' 	=> 'spotify',
			'label' 			=> esc_html__( 'Spotify', 'decree-pro' ),
		),
		'foursquare_link'	=> array(
			'fa_class' 	=> 'foursquare',
			'label' 			=> esc_html__( 'Foursquare', 'decree-pro' ),
		),
		'twitch_link'		=> array(
			'fa_class' 	=> 'twitch',
			'label' 			=> esc_html__( 'Twitch', 'decree-pro' ),
		),
		'website_link'		=> array(
			'fa_class' 	=> 'globe',
			'label' 			=> esc_html__( 'Website', 'decree-pro' ),
		),
		'phone_link'		=> array(
			'fa_class' => 'mobile-phone',
			'label'    => esc_html__( 'Phone', 'decree-pro' ),
		),
		'handset_link'		=> array(
			'fa_class' => 'phone',
			'label'    => esc_html__( 'Handset', 'decree-pro' ),
		),
		'cart_link'			=> array(
			'fa_class' => 'shopping-cart',
			'label'    => esc_html__( 'Cart', 'decree-pro' ),
		),
		'cloud_link'		=> array(
			'fa_class' => 'cloud',
			'label'    => esc_html__( 'Cloud', 'decree-pro' ),
		),
		'link_link'		=> array(
			'fa_class' => 'link',
			'label'    => esc_html__( 'Link', 'decree-pro' ),
		),
	);

	return apply_filters( 'decree_social_icons_list', $options );
}


/**
 * Returns list of basic color options currently supported
 *
 * @since Decree Pro 1.0
 */
/**
 * Returns list of basic color options currently supported
 *
 * @param  string $filter send data according to the filter value.
 * @return array list of color headings, or color inner items.
 */
function decree_get_color_options( $filter ) {
	$options = array(); // Initialize options.
	switch ( $filter ) {
		case 'color_headings':
			$options = array(
				'basic_color'             => esc_html__( 'Basic Colors', 'decree-pro' ),
				'contact_info_color'      => esc_html__( 'Footer Contact Info Colors', 'decree-pro' ),
				'contact_page_color'      => esc_html__( 'Consultation Form Colors', 'decree-pro' ),
				'content_color'           => esc_html__( 'Content Colors', 'decree-pro' ),
				'featured_content_color'  => esc_html__( 'Featured Content Colors', 'decree-pro' ),
				'footer_color'            => esc_html__( 'Footer Colors', 'decree-pro' ),
				'footer_menu_color'       => esc_html__( 'Footer Menu Colors', 'decree-pro' ),
				'header_color'            => esc_html__( 'Header Colors', 'decree-pro' ),
				'header_right_menu_color' => esc_html__( 'Header Right Menu Colors', 'decree-pro' ),
				'header_top_menu_color'   => esc_html__( 'Header Top Menu Colors', 'decree-pro' ),
				'hero_content_color'      => esc_html__( 'Hero Content Colors', 'decree-pro' ),
				'menu_color'              => esc_html__( 'Primary Menu Colors', 'decree-pro' ),
				'pagination_color'        => esc_html__( 'Pagination Colors', 'decree-pro' ),
				'portfolio_color'         => esc_html__( 'Portfolio Colors', 'decree-pro' ),
				'promo_head_color'        => esc_html__( 'Promotion Headline Colors', 'decree-pro' ),
				'scrollup_color'          => esc_html__( 'Scrollup Colors', 'decree-pro' ),
				'secondary_menu_color'    => esc_html__( 'Secondary Menu Colors', 'decree-pro' ),
				'sidebar_color'           => esc_html__( 'Sidebar Colors', 'decree-pro' ),
				'slider_color'            => esc_html__( 'Featured Slider Colors', 'decree-pro' ),
				'testimonial_color'       => esc_html__( 'Testimonial Slider Colors', 'decree-pro' ),
			);
		break;

		case 'basic_color':
			$options = array(
				'text_color'          => array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => 'body, button, input, select, textarea',
					'css_property' => 'color',
				),
				'link_color'          => array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => 'a',
					'css_property' => 'color',
				),
				'link_hover_color'    => array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => 'a:hover, a:focus, a:active',
					'css_property' => 'color',
				),
			);
		break;

		case 'contact_info_color':
			$options = array(
				'contact_info_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#contact-info-section .content-info-wrapper',
					'css_property' => 'background-color',
				),
				'contact_info_border_color' 	=> array(
					'label'        => esc_html__( 'Border Color', 'decree-pro' ),
					'css_selector' => '#contact-info-section .content-info-wrapper',
					'css_property' => 'border-color',
				),
				'contact_info_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#contact-info-section .content-info-wrapper',
					'css_property' => 'color',
				),
				'contact_info_link_color' 	=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#contact-info-section .content-info-wrapper a',
					'css_property' => 'color',
				),
				'contact_info_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#contact-info-section .content-info-wrapper a:hover, #contact-info-section .content-info-wrapper a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'contact_page_color':
			$options = array(
				'contact_page_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section',
					'css_property' => 'background-color',
				),
				'contact_page_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section',
					'css_property' => 'color',
				),
				'contact_page_link_color' 	=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section a',
					'css_property' => 'color',
				),
				'contact_page_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section a:hover, #contact-page-section a:focus',
					'css_property' => 'color',
				),
				'contact_page_title_color' 	=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section .entry-title, #contact-page-section .entry-title a',
					'css_property' => 'color',
				),
				'contact_page_title_hover_color' 	=> array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section .entry-title a:hover, #contact-page-section .entry-title a:focus',
					'css_property' => 'color',
				),
				'contact_page_form_fields_bg_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Background Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input, #contact-page-section form textarea, #contact-page-section form select',
					'css_property' => 'background-color',
				),
				'contact_page_form_fields_border_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Border Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input, #contact-page-section form textarea, #contact-page-section form select',
					'css_property' => 'border-color',
				),
				'contact_page_form_fields_text_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Text Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input, #contact-page-section form textarea, #contact-page-section form select',
					'css_property' => 'color',
				),
				'contact_page_form_fields_focus_bg_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Focus Background Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input:focus, #contact-page-section form textarea:focus, #contact-page-section form select:focus',
					'css_property' => 'background-color',
				),
				'contact_page_form_fields_focus_border_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Focus Border Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input:focus, #contact-page-section form textarea:focus, #contact-page-section form select:focus',
					'css_property' => 'border-color',
				),
				'contact_page_form_fields_focus_text_color' 	=> array(
					'label'        => esc_html__( 'Form Fields Focus Text Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input:focus, #contact-page-section form textarea:focus, #contact-page-section form select:focus',
					'css_property' => 'color',
				),
				'contact_page_submit_button_bg_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Background Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]',
					'css_property' => 'background-color',
				),
				'contact_page_submit_button_border_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Border Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]',
					'css_property' => 'border-color',
				),
				'contact_page_submit_button_text_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Text Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]',
					'css_property' => 'color',
				),
				'contact_page_submit_button_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]:hover, #contact-page-section form input[type="submit"]:focus',
					'css_property' => 'background-color',
				),
				'contact_page_submit_button_hover_border_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]:hover, #contact-page-section form input[type="submit"]:focus',
					'css_property' => 'border-color',
				),
				'contact_page_submit_button_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Submit Button Hover Tex Color', 'decree-pro' ),
					'css_selector' => '#contact-page-section form input[type="submit"]:hover, #contact-page-section form input[type="submit"]:focus',
					'css_property' => 'color',
				),

			);
		break;

		case 'content_color':
			$options = array(
				'content_wrapper_bg_color' 	=> array(
					'label'        => esc_html__( 'Content Wrapper Background Color', 'decree-pro' ),
					'css_selector' => '.site-content .wrapper',
					'css_property' => 'background-color',
				),
				'content_bg_color' 	=> array(
					'label'        => esc_html__( 'Content Background Color', 'decree-pro' ),
					'css_selector' => '.site-main',
					'css_property' => 'background-color',
				),
				'content_title_color' 	=> array(
					'label'        => esc_html__( 'Content Title Color', 'decree-pro' ),
					'css_selector' => '.page-title, #main .entry-title, #main .entry-title a',
					'css_property' => 'color',
				),
				'content_title_hover_color' 	=> array(
					'label'        => esc_html__( 'Content Title Hover Color', 'decree-pro' ),
					'css_selector' => '#main .entry-title a:hover, #main .entry-title a:focus',
					'css_property' => 'color',
				),
				'content_meta_color' 	=> array(
					'label'        => esc_html__( 'Content Meta Color', 'decree-pro' ),
					'css_selector' => '#main .entry-meta, #main .entry-meta a',
					'css_property' => 'color',
				),
				'content_meta_hover_color' 	=> array(
					'label'        => esc_html__( 'Content Meta Hover Color', 'decree-pro' ),
					'css_selector' => '#main .entry-meta a:hover, #main .entry-meta a:focus',
					'css_property' => 'color',
				),
				'sticky_post_title_bg_color' 	=> array(
					'label'        => esc_html__( 'Sticky Post Title Background Color', 'decree-pro' ),
					'css_selector' => '.hentry.sticky .sticky-label',
					'css_property' => 'background-color',
				),
				'sticky_post_title_text_color' 	=> array(
					'label'        => esc_html__( 'Sticky Post Title Text Color', 'decree-pro' ),
					'css_selector' => '.hentry.sticky .sticky-label',
					'css_property' => 'color',
				),
			);
		break;

		case 'featured_content_color':
			$options = array(
				'featured_content_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#featured-content',
					'css_property' => 'background-color',
				),
				'featured_content_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#featured-content',
					'css_property' => 'color',
				),
				'featured_content_headline_color' 	=> array(
					'label'        => esc_html__( 'Headline Color', 'decree-pro' ),
					'css_selector' => '#featured-content .section-heading-wrap .entry-title',
					'css_property' => 'color',
				),
				'featured_content_subheadline_color' 	=> array(
					'label'        => esc_html__( 'Subheadline Color', 'decree-pro' ),
					'css_selector' => '#featured-content .section-heading-wrap',
					'css_property' => 'color',
				),
				'featured_content_title_color' 	=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => '#featured-content .featured-content-wrap .entry-title, #featured-content .featured-content-wrap .entry-title a',
					'css_property' => 'color',
				),
				'featured_content_title_hover_color' 	=> array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '#featured-content .featured-content-wrap .entry-title a:hover, #featured-content .featured-content-wrap .entry-title a:focus',
					'css_property' => 'color',
				),
				'featured_content_link_color' 	=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#featured-content a',
					'css_property' => 'color',
				),
				'featured_content_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#featured-content a:hover, #featured-content a:focus',
					'css_property' => 'color',
				),
				'featured_content_button_bg_color' 	=> array(
					'label'        => esc_html__( 'Button Background Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal',
					'css_property' => 'background-color',
				),
				'featured_content_button_border_color' 	=> array(
					'label'        => esc_html__( 'Button Border Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal',
					'css_property' => 'border-color',
				),
				'featured_content_button_text_color' 	=> array(
					'label'        => esc_html__( 'Button Text Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal',
					'css_property' => 'color',
				),
				'featured_content_button_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Backgroung Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal:hover, #featured-content .more-button .button-minimal:focus',
					'css_property' => 'background-color',
				),
				'featured_content_button_hover_border_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal:hover, #featured-content .more-button .button-minimal:focus',
					'css_property' => 'border-color',
				),
				'featured_content_button_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Text Color', 'decree-pro' ),
					'css_selector' => '#featured-content .more-button .button-minimal:hover, #featured-content .more-button .button-minimal:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'footer_color':
			$options = array(
				'footer_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#site-generator',
					'css_property' => 'background-color',
				),
				'footer_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#site-generator',
					'css_property' => 'color',
				),
				'footer_link_color' 	=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#site-generator a',
					'css_property' => 'color',
				),
				'footer_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#site-generator a:hover, #site-generator a:focus',
					'css_property' => 'color',
				),
				'footer_sidebar_area_bg_color' 	=> array(
					'label'        => esc_html__( 'Sidebar Area Background Color', 'decree-pro' ),
					'css_selector' => '.site-footer',
					'css_property' => 'background-color',
				),
				'footer_widget_text_color' 	=> array(
					'label'        => esc_html__( 'Widget Text Color', 'decree-pro' ),
					'css_selector' => '.site-footer, .site .footer-widget-area .widget_decree_social_icons a',
					'css_property' => 'color',
				),
				'footer_widget_title_color' 	=> array(
					'label'        => esc_html__( 'Widget Title Color', 'decree-pro' ),
					'css_selector' => '.footer-widget-area .widget-title, .footer-widget-area .entry-title, .footer-widget-area .widget-title a, .footer-widget-area .entry-title a',
					'css_property' => 'color',
				),
				'footer_widget_link_color' 	=> array(
					'label'        => esc_html__( 'Widget Link Color', 'decree-pro' ),
					'css_selector' => '.footer-widget-area a',
					'css_property' => 'color',
				),
				'footer_widget_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Widget Link Hover Color', 'decree-pro' ),
					'css_selector' => '.footer-widget-area a:hover, .footer-widget-area a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'header_color':
			$options = array(
				'header_bg_color' => array(
					'label'        => esc_html__( 'Header Background color', 'decree-pro' ),
					'css_selector' => '#masthead',
					'css_property' => 'background-color',
				),
				'site_title_hover_color'  => array(
					'label'        => esc_html__( 'Site Title Hover Color', 'decree-pro' ),
					'css_selector' => '.site-title a:hover, .site-title a:focus',
					'css_property' => 'color',
				),
				'tagline_color'           => array(
					'label'        => esc_html__( 'Tagline Color', 'decree-pro' ),
					'css_selector' => '.site-description',
					'css_property' => 'color',
				),
				'header_right_title_color'           => array(
					'label'        => esc_html__( 'Header Right Title Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .widget-title',
					'css_property' => 'color',
				),
				'header_right_button_bg_color'           => array(
					'label'        => esc_html__( 'Header Right Button Background Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal',
					'css_property' => 'background-color',
				),
				'header_right_button_border_color'           => array(
					'label'        => esc_html__( 'Header Right Button Border Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal',
					'css_property' => 'border-color',
				),
				'header_right_button_text_color'           => array(
					'label'        => esc_html__( 'Header Right Button Text Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal',
					'css_property' => 'color',
				),
				'header_right_button_hover_bg_color'           => array(
					'label'        => esc_html__( 'Header Right Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal:hover, #call-to-action-widget .button-minimal:focus',
					'css_property' => 'background-color',
				),
				'header_right_button_hover_border_color'           => array(
					'label'        => esc_html__( 'Header Right Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal:hover, #call-to-action-widget .button-minimal:focus',
					'css_property' => 'border-color',
				),
				'header_right_button_hover_text_color'           => array(
					'label'        => esc_html__( 'Header Right Button Hover Text Color', 'decree-pro' ),
					'css_selector' => '#call-to-action-widget .button-minimal:hover, #call-to-action-widget .button-minimal:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'hero_content_color':
			$options = array(
				'hero_bg_color'	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#hero-section',
					'css_property' => 'background-color',
				),
				'hero_text_color'		=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#hero-section',
					'css_property' => 'color',
				),
				'hero_content_bg_color'		=> array(
					'label'        => esc_html__( 'Content Background Color', 'decree-pro' ),
					'css_selector' => '#hero-section .entry-container-wrap',
					'css_property' => 'background-color',
				),
				'hero_title_color'		=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => '#hero-section .entry-title, #hero-section .entry-title a',
					'css_property' => 'color',
				),
				'hero_title_hover_color' => array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '#hero-section .entry-title a:hover, #hero-section .entry-title a:focus',
					'css_property' => 'color',
				),
				'hero_link_color'		=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#hero-section .entry-color a',
					'css_property' => 'color',
				),
				'hero_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#hero-section .entry-color a:hover, #hero-section .entry-color a:focus',
					'css_property' => 'color',
				),
				'hero_button_bg_color'		=> array(
					'label'        => esc_html__( 'Button Background Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal',
					'css_property' => 'background-color',
				),
				'hero_button_border_color'	=> array(
					'label'        => esc_html__( 'Button Border Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal',
					'css_property' => 'border-color',
				),
				'hero_button_text_color'	=> array(
					'label'        => esc_html__( 'Button Text Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal',
					'css_property' => 'color',
				),
				'hero_button_hover_bg_color'		=> array(
					'label'        => esc_html__( 'Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal:hover, #hero-section .button-minimal:focus',
					'css_property' => 'background-color',
				),
				'hero_button_hover_border_color'	=> array(
					'label'        => esc_html__( 'Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal:hover, #hero-section .button-minimal:focus',
					'css_property' => 'border-color',
				),
				'hero_button_hover_text_color'	=> array(
					'label'        => esc_html__( 'Button Hover Text Color', 'decree-pro' ),
					'css_selector' => '#hero-section .button-minimal:hover, #hero-section .button-minimal:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'pagination_color':
			$options = array(
				'pagination_bg_color'                    => array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a, .pagination .nav-links a, .pagination .nav-links .dots, .wp-pagenavi a, .wp-pagenavi span, .site-main #infinite-handle span button, .woocommerce nav.woocommerce-pagination ul li a, .woocommerce nav.woocommerce-pagination ul li span, .wp-pagenavi a, .wp-pagenavi span, .page-links a, .page-links span',
					'css_property' => 'background-color',
				),
				'pagination_border_color'                        => array(
					'label'        => esc_html__( 'Border Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a, .pagination .nav-links a, .pagination .nav-links .dots, .wp-pagenavi a, .wp-pagenavi span, .site-main #infinite-handle span button, .woocommerce nav.woocommerce-pagination ul li a, .woocommerce nav.woocommerce-pagination ul li span, .wp-pagenavi a, .wp-pagenavi span, .page-links a, .page-links span',
					'css_property' => 'border-color',
				),
				'pagination_link_color'                          => array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a, .pagination .nav-links a, .pagination .nav-links .dots, .wp-pagenavi a, .wp-pagenavi span, .site-main #infinite-handle span button, .woocommerce nav.woocommerce-pagination ul li a, .woocommerce nav.woocommerce-pagination ul li span, .wp-pagenavi a, .wp-pagenavi span, .page-links a, .page-links span',
					'css_property' => 'color',
				),
				'pagination_hover_active_bg_color'              => array(
					'label'        => esc_html__( 'Hover/Active Background Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a:hover, .posts-navigation .nav-links a:focus, .pagination .nav-links a:hover, .pagination .nav-links a:focus, .pagination .nav-links .current, .wp-pagenavi span.current, .wp-pagenavi a:hover, .wp-pagenavi a:focus, .site-main #infinite-handle span button:hover, .site-main #infinite-handle span button:focus, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, .page-links span, .page-links a:hover, .page-links a:focus, .page-links a:hover span, .page-links a:focus span',
					'css_property' => 'background-color',
				),
				'pagination_hover_active_border_color'              => array(
					'label'        => esc_html__( 'Hover/Active Border Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a:hover, .posts-navigation .nav-links a:focus, .pagination .nav-links a:hover, .pagination .nav-links a:focus, .pagination .nav-links .current, .wp-pagenavi span.current, .wp-pagenavi a:hover, .wp-pagenavi a:focus, .site-main #infinite-handle span button:hover, .site-main #infinite-handle span button:focus, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, .page-links span, .page-links a:hover, .page-links a:focus, .page-links a:hover span, .page-links a:focus span',
					'css_property' => 'border-color',
				),
				'pagination_hover_active_link_color'              => array(
					'label'        => esc_html__( 'Hover/Active Link Color', 'decree-pro' ),
					'css_selector' => '.posts-navigation .nav-links a:hover, .posts-navigation .nav-links a:focus, .pagination .nav-links a:hover, .pagination .nav-links a:focus, .pagination .nav-links .current, .wp-pagenavi span.current, .wp-pagenavi a:hover, .wp-pagenavi a:focus, .site-main #infinite-handle span button:hover, .site-main #infinite-handle span button:focus, .woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current, .page-links span, .page-links a:hover, .page-links a:focus, .page-links a:hover span, .page-links a:focus span',
					'css_property' => 'color',
				),
			);
		break;

		case 'promo_head_color':
			$options = array(
				'promo_head_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section',
					'css_property' => 'background-color',
				),
				'promo_head_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section',
					'css_property' => 'color',
				),
				'promo_head_title_color' 	=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => ' #promotion-headline-section .entry-title, #promotion-headline-section .entry-title a',
					'css_property' => 'color',
				),
				'promo_head_title_hover_color' 	=> array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .entry-title a:hover, #promotion-headline-section .entry-title a:focus ',
					'css_property' => 'color',
				),
				'promo_head_link_color' 	=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section a',
					'css_property' => 'color',
				),
				'promo_head_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section a:hover, #promotion-headline-section a:focus',
					'css_property' => 'color',
				),
				'promo_head_button_bg_color' 	=> array(
					'label'        => esc_html__( 'Button Background Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal',
					'css_property' => 'background-color',
				),
				'promo_head_button_text_color' 	=> array(
					'label'        => esc_html__( 'Button Text Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal',
					'css_property' => 'color',
				),
				'promo_head_button_border_color' 	=> array(
					'label'        => esc_html__( 'Button Border Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal',
					'css_property' => 'border-color',
				),
				'promo_head_button_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal:hover, #promotion-headline-section .button-minimal:focus',
					'css_property' => 'background-color',
				),
				'promo_head_button_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Text Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal:hover, #promotion-headline-section .button-minimal:focus',
					'css_property' => 'color',
				),
				'promo_head_button_hover_border_color' 	=> array(
					'label'        => esc_html__( 'Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#promotion-headline-section .button-minimal:hover, #promotion-headline-section .button-minimal:focus',
					'css_property' => 'border-color',
				),
			);
		break;

		case 'scrollup_color':
			$options = array(
				'scrollup_bg_color' 	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#scrollup',
					'css_property' => 'background-color',
				),
				'scrollup_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Hover Background Color', 'decree-pro' ),
					'css_selector' => '#scrollup:hover, #scrollup:focus',
					'css_property' => 'background-color',
				),
				'scrollup_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#scrollup',
					'css_property' => 'color',
				),
				'scrollup_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Hover Text Color', 'decree-pro' ),
					'css_selector' => '#scrollup:hover, #scrollup:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'portfolio_color':
			$options = array(
				'portfolio_bg_color'	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#portfolios-content',
					'css_property' => 'background-color',
				),
				'portfolio_text_color'		=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '.portfolio-wrap',
					'css_property' => 'color',
				),
				'portfolio_link_color'		=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '.portfolio-wrap a',
					'css_property' => 'color',
				),
				'portfolio_link_hover_color' 	=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '.portfolio-wrap a:hover, .portfolio-wrap a:focus',
					'css_property' => 'color',
				),
				'portfolio_headline_hover_color'		=> array(
					'label'        => esc_html__( 'Headine Color', 'decree-pro' ),
					'css_selector' => '.portfolio-heading-wrap .entry-title, .portfolio-heading-wrap .entry-title a',
					'css_property' => 'color',
				),
				'portfolio_subheadline_color'		=> array(
					'label'        => esc_html__( 'Subheadline Color', 'decree-pro' ),
					'css_selector' => '.portfolio-heading-wrap',
					'css_property' => 'color',
				),
				'portfolio_title_color'		=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => '.portfolio-wrap .entry-title, .portfolio-wrap .entry-title a',
					'css_property' => 'color',
				),
				'portfolio_title_hover_color' => array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '.portfolio-wrap .entry-title a:hover, .portfolio-wrap .entry-title a:focus',
					'css_property' => 'color',
				),
				'portfolio_meta_color'		=> array(
					'label'        => esc_html__( 'Meta Color', 'decree-pro' ),
					'css_selector' => '#portfolios-content .entry-meta a',
					'css_property' => 'color',
				),
				'portfolio_meta_hover_color'	=> array(
					'label'        => esc_html__( 'Meta Hover Color', 'decree-pro' ),
					'css_selector' => '#portfolios-content .entry-meta a:hover, #portfolios-content .entry-meta a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'menu_color':
			$options = array(
				'menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Background color', 'decree-pro' ),
					'css_selector' => '.menu-primary ',
					'css_property' => 'background-color',
				),
				'menu_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu a',
					'css_property' => 'color',
				),
				'hover_active_bg_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Background Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu a:hover, .menu-primary .decree-nav-menu a:focus, .menu-primary .decree-nav-menu .current-menu-item > a, .menu-primary .decree-nav-menu .current-menu-ancestor > a, .menu-primary .decree-nav-menu .current_page_item > a, .menu-primary .decree-nav-menu .current_page_ancestor > a',
					'css_property' => 'background-color',
				),
				'hover_active_text_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Text Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu a:hover, .menu-primary .decree-nav-menu a:focus, .menu-primary .decree-nav-menu .current-menu-item > a, .menu-primary .decree-nav-menu .current-menu-ancestor > a, .menu-primary .decree-nav-menu .current_page_item > a, .menu-primary .decree-nav-menu .current_page_ancestor > a',
					'css_property' => 'color',
				),
				'sub_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Background Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu ul',
					'css_property' => 'background-color',
				),
				'sub_menu_border_top_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Top Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu ul',
					'css_property' => 'border-color',
				),
				'sub_menu_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Text Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu .sub-menu a',
					'css_property' => 'color',
				),
				'sub_menu_border_between_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Between Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu .sub-menu li',
					'css_property' => ' border-color',
				),
				'sub_menu_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Background Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu ul a:hover, .menu-primary .decree-nav-menu ul a:focus',
					'css_property' => ' background-color',
				),
				'sub_menu_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Text Color', 'decree-pro' ),
					'css_selector' => '.menu-primary .decree-nav-menu ul a:hover, .menu-primary .decree-nav-menu ul a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'secondary_menu_color':
			$options = array(
				'sec_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Background color', 'decree-pro' ),
					'css_selector' => '.menu-secondary',
					'css_property' => 'background-color',
				),
				'sec_menu_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu a',
					'css_property' => 'color',
				),
				'sec_hover_active_bg_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Background Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu a:hover, .menu-secondary .decree-nav-menu a:focus, .menu-secondary .decree-nav-menu .current-menu-item > a, .menu-secondary .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'background-color',
				),
				'sec_hover_active_text_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Text Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu a:hover, .menu-secondary .decree-nav-menu a:focus, .menu-secondary .decree-nav-menu .current-menu-item > a, .menu-secondary .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'color',
				),
				'sec_sub_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Background Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu .sub-menu a',
					'css_property' => 'background-color',
				),
				'sec_sub_menu_border_top_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Top Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu ul',
					'css_property' => 'border-color',
				),
				'sec_sub_menu_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Text Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu .sub-menu a',
					'css_property' => 'color',
				),
				'sec_sub_menu_border_between_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Between Color', 'decree-pro' ),
					'css_selector' => '.menu-secondary .decree-nav-menu .sub-menu li',
					'css_property' => 'border-color',
				),
			);
		break;

		case 'header_top_menu_color':
			$options = array(
				'header_top_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Background color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu a',
					'css_property' => 'background-color',
				),
				'header_top_menu_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu a',
					'css_property' => 'color',
				),
				'header_top_hover_active_bg_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Background Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu a:hover, .header-top-bar .decree-nav-menu a:focus, .header-top-bar .decree-nav-menu .current-menu-item > a, .header-top-bar .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'background-color',
				),
				'header_top_hover_active_text_color' 	=> array(
					'label'        => esc_html__( 'Hover/Active Text Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu a:hover, .header-top-bar .decree-nav-menu a:focus, .header-top-bar .decree-nav-menu .current-menu-item > a, .header-top-bar .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'color',
				),
				'header_top_sub_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Background Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu .sub-menu a',
					'css_property' => 'background-color',
				),
				'header_top_sub_menu_border_top_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Top Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu ul',
					'css_property' => 'border-color',
				),
				'header_top_sub_menu_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Text Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu .sub-menu a',
					'css_property' => 'color',
				),
				'header_top_sub_menu_border_between_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Between Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu .sub-menu li',
					'css_property' => 'border-color',
				),
				'header_top_sub_menu_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Background Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu .sub-menu a:hover, .header-top-bar .decree-nav-menu .sub-menu a:focus',
					'css_property' => 'background-color',
				),
				'header_top_sub_menu_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Text Color', 'decree-pro' ),
					'css_selector' => '.header-top-bar .decree-nav-menu .sub-menu a:hover, .header-top-bar .decree-nav-menu .sub-menu a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'header_right_menu_color':
			$options = array(
				'header_right_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Background color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu a',
					'css_property' => 'background-color',
				),
				'header_right_menu_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu a',
					'css_property' => 'color',
				),
				'header_right_hover_active_bg_color' 	=> array(
					'label'        => esc_html__( 'Hover Active Background Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu a:hover, .menu-header-right .decree-nav-menu a:focus, .menu-header-right .decree-nav-menu .current-menu-item > a, .menu-header-right .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'background-color',
				),
				'header_right_hover_active_text_color' 	=> array(
					'label'        => esc_html__( 'Hover Active Text Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu a:hover, .menu-header-right .decree-nav-menu a:focus, .menu-header-right .decree-nav-menu .current-menu-item > a, .menu-header-right .decree-nav-menu .current-menu-ancestor > a',
					'css_property' => 'color',
				),
				'header_right_sub_menu_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Background Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu ul',
					'css_property' => 'background-color',
				),
				'header_right_sub_menu_border_top_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Top Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu ul',
					'css_property' => 'border-color',
				),
				'header_right_sub_menu_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Text Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu .sub-menu a',
					'css_property' => 'color',
				),
				'header_right_sub_menu_border_between_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Border Between', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu .sub-menu li ',
					'css_property' => 'border-color',
				),
				'header_right_sub_menu_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Background Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu .sub-menu a:hover, .menu-header-right .decree-nav-menu .sub-menu a:focus',
					'css_property' => 'background-color',
				),
				'header_right_sub_menu_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Sub Menu Hover Text Color', 'decree-pro' ),
					'css_selector' => '.menu-header-right .decree-nav-menu .sub-menu a:hover, .menu-header-right .decree-nav-menu .sub-menu a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'footer_menu_color':
			$options = array(
				'footer_menu_bg_color'         => array(
					'label'        => esc_html__( 'Menu Background color', 'decree-pro' ),
					'css_selector' => '#site-generator .decree-nav-menu li a',
					'css_property' => 'background-color',
				),
				'footer_menu_color'                    => array(
					'label'        => esc_html__( 'Menu Text Color', 'decree-pro' ),
					'css_selector' => '#site-generator .decree-nav-menu li a',
					'css_property' => 'color',
				),
				'footer_hover_active_bg_color' => array(
					'label'        => esc_html__( 'Hover Active Background Color', 'decree-pro' ),
					'css_selector' => '#site-generator .decree-nav-menu .current-menu-item a, #site-generator .decree-nav-menu li a:hover, #site-generator .decree-nav-menu li a:focus',
					'css_property' => 'background-color',
				),
				'footer_hover_active_text_color'       => array(
					'label'        => esc_html__( 'Hover Active Text Color', 'decree-pro' ),
					'css_selector' => '#site-generator .decree-nav-menu .current-menu-item a, #site-generator .decree-nav-menu li a:hover, #site-generator .decree-nav-menu li a:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'sidebar_color':
			$options = array(
				'sidebar_bg_color' 	=> array(
					'label'        => esc_html__( 'Sidebar Background Color', 'decree-pro' ),
					'css_selector' => '.site-content .widget-area',
					'css_property' => 'background-color',
				),
				'sidebar_title_color' 	=> array(
					'label'        => esc_html__( 'Sidebar Title Color', 'decree-pro' ),
					'css_selector' => '.site-content .widget-title, .site-content .widget-title a',
					'css_property' => 'color',
				),
				'sidebar_link_color' 	=> array(
					'label'        => esc_html__( 'Sidebar Link Color', 'decree-pro' ),
					'css_selector' => '.site-content .widget-area a',
					'css_property' => 'color',
				),
				'sidebar_link_hover_color' => array(
					'label'        => esc_html__( 'Sidebar Link Hover Color', 'decree-pro' ),
					'css_selector' => '.site-content .widget-area a:hover, .site-content .widget-area a:focus',
					'css_property' => 'color',
				),
				'newsletter_form_bg_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Form Background Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap',
					'css_property' => 'background-color',
				),
				'newsletter_form_text_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Form Text Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap',
					'css_property' => 'color',
				),
				'newsletter_fields_bg_color' => array(
					'label'        => esc_html__( 'Newsletter Fields Background Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input',
					'css_property' => 'background-color',
				),
				'newsletter_fields_text_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Fields Text Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input',
					'css_property' => 'color',
				),
				'newsletter_fields_border_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Fields Border Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input',
					'css_property' => 'border-color',
				),
				'newsletter_fields_focus_bg_color' => array(
					'label'        => esc_html__( 'Newsletter Fields Focus Background Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input:focus',
					'css_property' => 'background-color',
				),
				'newsletter_fields_focus_text_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Fields Focus Text Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input:focus',
					'css_property' => 'color',
				),
				'newsletter_fields_focus_border_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Fields Focus Border Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .widget-wrap input:focus',
					'css_property' => 'border-color',
				),
				'newsletter_submit_button_bg_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Submit Button Background Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .ct-newsletter-wrap #subbutton',
					'css_property' => 'background-color',
				),
				'newsletter_submit_button_text_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Submit Button Text Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .ct-newsletter-wrap #subbutton',
					'css_property' => 'color',
				),
				'newsletter_submit_button_hover_bg_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Submit Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .ct-newsletter-wrap #subbutton:focus, .ctnewsletter .ct-newsletter-wrap #subbutton:hover',
					'css_property' => 'background-color',
				),
				'newsletter_submit_button_hover_text_color' 	=> array(
					'label'        => esc_html__( 'Newsletter Submit Button Hover Text Color', 'decree-pro' ),
					'css_selector' => '.ctnewsletter .ct-newsletter-wrap #subbutton:focus, .ctnewsletter .ct-newsletter-wrap #subbutton:hover',
					'css_property' => 'color',
				),
			);
		break;

		case 'slider_color':
			$options = array(
				'slider_bg_color'	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#feature-slider',
					'css_property' => 'background-color',
				),
				'slider_content_bg_color'	=> array(
					'label'        => esc_html__( 'Content Background Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .container',
					'css_property' => 'background-color',
				),
				'slider_title_color'				=> array(
					'label'        => esc_html__( 'Title Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .entry-title, #feature-slider .entry-title a',
					'css_property' => 'color',
				),
				'slider_title_hover_color'			=> array(
					'label'        => esc_html__( 'Title Hover Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .entry-title a:hover, #feature-slider .entry-title a:focus',
					'css_property' => 'color',
				),
				'slider_text_color'					=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .entry-summary',
					'css_property' => 'color',
				),
				'slider_link_color'					=> array(
					'label'        => esc_html__( 'Link Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .entry-summary a',
					'css_property' => 'color',
				),
				'slider_link_hover_color'			=> array(
					'label'        => esc_html__( 'Link Hover Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .entry-summary a:hover, #feature-slider .entry-summary a:focus',
					'css_property' => 'color',
				),
				'slider_button_bg_color'					=> array(
					'label'        => esc_html__( 'Button Background Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal',
					'css_property' => 'background-color',
				),
				'slider_button_border_color'					=> array(
					'label'        => esc_html__( 'Button Border Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal',
					'css_property' => 'border-color',
				),
				'slider_button_link_color'			=> array(
					'label'        => esc_html__( 'Button Link Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal',
					'css_property' => 'color',
				),
				'slider_button_hover_bg_color'					=> array(
					'label'        => esc_html__( 'Button Hover Background Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal:hover, #feature-slider .more-button .button-minimal:focus',
					'css_property' => 'background-color',
				),
				'slider_button_hover_border_color'					=> array(
					'label'        => esc_html__( 'Button Hover Border Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal:hover, #feature-slider .more-button .button-minimal:focus',
					'css_property' => 'border-color',
				),
				'slider_button_hover_link_color'			=> array(
					'label'        => esc_html__( 'Button Hover Link Color', 'decree-pro' ),
					'css_selector' => '#feature-slider .more-button .button-minimal:hover, #feature-slider .more-button .button-minimal:focus',
					'css_property' => 'color',
				),
			);
		break;

		case 'testimonial_color':
			$options = array(
				'testimonial_bg_color'	=> array(
					'label'        => esc_html__( 'Background Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section',
					'css_property' => 'background-color',
				),
				'testimonial_headline_color'		=> array(
					'label'        => esc_html__( 'Headline Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section .section-heading-wrap .entry-title',
					'css_property' => 'color',
				),
				'testimonial_subheadline_color'		=> array(
					'label'        => esc_html__( 'Subheadline Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section .section-heading-wrap',
					'css_property' => 'color',
				),
				'testimonial_text_color' 	=> array(
					'label'        => esc_html__( 'Text Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section .section-content-wrap',
					'css_property' => 'color',
				),
				'testimonial_name_color'		=> array(
					'label'        => esc_html__( 'Name Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section .section-content-wrap .entry-title a',
					'css_property' => 'color',
				),
				'testimonial_position_color' => array(
					'label'        => esc_html__( 'Position Color', 'decree-pro' ),
					'css_selector' => '#testimonial-section .entry-meta',
					'css_property' => 'color',
				),
			);
		break;
	} // End switch().

	return $options;
}
add_filter( 'decree_color_options', 'decree_get_color_options' );


/**
 * Returns an array of metabox layout options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_metabox_layouts() {
	$layout_options = array(
		'default' 	=> array(
			'id' 	=> 'decree-layout-option',
			'value' => 'default',
			'label' => esc_html__( 'Default', 'decree-pro' ),
		),
		'left-sidebar' 	=> array(
			'id' 	=> 'decree-layout-option',
			'value' => 'left-sidebar',
			'label' => esc_html__( 'Primary Sidebar, Content', 'decree-pro' ),
		),
		'right-sidebar' => array(
			'id' 	=> 'decree-layout-option',
			'value' => 'right-sidebar',
			'label' => esc_html__( 'Content, Primary Sidebar', 'decree-pro' ),
		),
		'no-sidebar'	=> array(
			'id' 	=> 'decree-layout-option',
			'value' => 'no-sidebar',
			'label' => esc_html__( 'No Sidebar ( Content Width )', 'decree-pro' ),
		),
		'no-sidebar-one-column' => array(
			'id' 	=> 'decree-layout-option',
			'value' => 'no-sidebar-one-column',
			'label' => esc_html__( 'No Sidebar ( One Column )', 'decree-pro' ),
		),
		'no-sidebar-full-width' => array(
			'id' 	=> 'decree-layout-option',
			'value' => 'no-sidebar-full-width',
			'label' => esc_html__( 'No Sidebar ( Full Width )', 'decree-pro' ),
		),
	);
	return apply_filters( 'decree_layouts', $layout_options );
}

/**
 * Returns an array of metabox header featured image options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_metabox_header_featured_image_options() {
	$options = array(
		'default' => array(
			'id'		=> 'decree-header-image',
			'value' 	=> 'default',
			'label' 	=> esc_html__( 'Default', 'decree-pro' ),
		),
		'enable'  => array(
			'id'		=> 'decree-header-image',
			'value' 	=> 'enable',
			'label' 	=> esc_html__( 'Enable', 'decree-pro' ),
		),
		'disable' => array(
			'id'		=> 'decree-header-image',
			'value' 	=> 'disable',
			'label' 	=> esc_html__( 'Disable', 'decree-pro' ),
		),
	);
	return apply_filters( 'header_featured_image_options', $options );
}


/**
 * Returns an array of metabox sidebar options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_metabox_sidebar_options() {
	$options = array(
		'main-sidebar' => array(
			'id'		=> 'decree-sidebar-options',
			'value' 	=> 'default-sidebar',
			'label' 	=> esc_html__( 'Default Sidebar', 'decree-pro' ),
		),
		'optional-sidebar-one' => array(
			'id' 	=> 'decree-sidebar-options',
			'value' => 'optional-sidebar-one',
			'label' => esc_html__( 'Optional Sidebar One', 'decree-pro' ),
		),
		'optional-sidebar-two' => array(
			'id' 	=> 'decree-sidebar-options',
			'value' => 'optional-sidebar-two',
			'label' => esc_html__( 'Optional Sidebar Two', 'decree-pro' ),
		),
		'optional-sidebar-three' => array(
			'id' 	=> 'decree-sidebar-options',
			'value' => 'optional-sidebar-three',
			'label' => esc_html__( 'Optional Sidebar three', 'decree-pro' ),
		),
	);
	return apply_filters( 'sidebar_options', $options );
}


/**
 * Returns an array of metabox featured image options registered for Decree.
 *
 * @since Decree Pro 1.0
 */
function decree_metabox_featured_image_options() {
	$options['default'] = array(
		'id'	=> 'decree-featured-image',
		'value' => 'default',
		'label' => esc_html__( 'Default', 'decree-pro' ),
	);

	$options['disabled'] = array(
		'id' 	=> 'decree-featured-image',
		'value' => 'disabled',
		'label' => esc_html__( 'Disable Image', 'decree-pro' ),
	);

	$options['decree-featured'] = array(
		'id' 	=> 'decree-featured-image',
		'value' => 'decree-featured',
		'label' => esc_html__( 'Featured', 'decree-pro' ),
	);

	$options['decree-featured-full'] = array(
		'id' 	=> 'decree-featured-image',
		'value' => 'decree-featured-full',
		'label' => esc_html__( 'Featured Full Width', 'decree-pro' ),
	);

	$options['full'] = array(
		'id'	=> 'decree-featured-image',
		'value'	=> 'full',
		'label' => esc_html__( 'Original', 'decree-pro' ),
	);

	return apply_filters( 'decree_metabox_featured_image_options', $options );
}


/**
 * Returns an array of feature slider transition effects
 *
 * @since Decree Pro 1.0
 */
function decree_contact_info_bg() {
	$options = array(
		'none'       => esc_html__( 'None', 'decree-pro' ),
		'image'      => esc_html__( 'Image', 'decree-pro' ),
		'embed-code' => esc_html__( 'Embed Code', 'decree-pro' ),
	);

	return apply_filters( 'decree_contact_info_bg', $options );
}


/**
 * Returns an array of hero content types registered for decree.
 *
 * @since Decree Pro 1.0
 */
function decree_get_category_list() {
	$cats    = get_categories();

	foreach ( $cats as $cat ) {
		$options[ $cat->term_id ] = $cat->name;
	}

	return apply_filters( 'decree_get_category_list', $options );
}


/**
 * Checks if there are options already present from Decree free version and adds it to the Decree Pro theme options
 *
 * @since Decree Pro 1.0
 * @hook after_theme_switch
 */
function decree_setup_options( $old_theme_name ) {
	if ( $old_theme_name ) {
		$old_theme_slug = sanitize_title( $old_theme_name );

		$free_version_slug = 'decree';
		$pro_version_slug  = 'decree-pro';

		$free_options = get_option( 'theme_mods_' . $old_theme_slug );

		// Perform action only if options of free version exists and theme is being switched from free version
		if ( $free_version_slug === $old_theme_slug && $free_options && '1' !== get_theme_mod( 'free_pro_migration' ) ) {
			$new_options = wp_parse_args( get_theme_mods(), $free_options );

			if ( update_option( 'theme_mods_' . $pro_version_slug, $free_options ) ) {
				// Set Migration Parameter to true so that this script does not run multiple times.
				set_theme_mod( 'free_pro_migration', '1' );
			}
		}
	}
}
add_action( 'after_switch_theme', 'decree_setup_options', 100 );
