<?php
/**
 * The template for displaying the Featured Content
 *
 * @package Decree Pro
 */


if ( ! function_exists( 'decree_featured_content_display' ) ) :
	/**
	* Add Featured content.
	*
	* @uses action hook decree_before_content.
	*
	* @since Decree Pro 1.0
	*/
	function decree_featured_content_display() {
		//decree_flush_transients();
		// get data value from options
		$output         = '';
		$options        = decree_get_theme_options();
		$enable_content = $options['featured_content_option'];
		$content_select = $options['featured_content_type'];

		if ( decree_check_section( $enable_content ) ) {
			if ( ! $output = get_transient( 'decree_featured_content' ) ) {
				$layouts 	 = $options['featured_content_layout'];
				$headline 	 = $options['featured_content_headline'];
				$subheadline = $options['featured_content_subheadline'];

				echo '<!-- refreshing cache -->';

				$classes[] = $layouts;
				$classes[] = $content_select;

				$position = $options['featured_content_position'];

				if ( $position ) {
					$classes[] = ' border-top' ;
				}

				$output = '
					<div id="featured-content" class="sections ' . esc_attr( implode( ' ', $classes ) ) . '" role="complementary">
						<div class="wrapper">';

				if ( 'demo' === $content_select ) {
					$output .= '
					<div class="section-heading-wrap">';

					$output .= '
						<div class="entry-header">
							<h2 class="section-title entry-title">Featured Content</h2>
						</div><!-- .entry-header -->

						<p>This is Featured Content.';

					if ( current_user_can( 'edit_theme_options' ) ) {
						$output .= ' You can edit this from Appearance - Customize - Theme Options - Featured Content. Detailed information of Featured Content can be found in our theme instructions page.';
					}

					$output .= '</p>
					</div><!-- .section-heading-wrap -->';
				} elseif ( ! empty( $headline ) || ! empty( $subheadline ) ) {
					$output .= '<div class="section-heading-wrap">';

					if ( ! empty( $headline ) ) {
						$output .= '<div class="entry-header"><h2 class="section-title entry-title">' . wp_kses_post( $headline ) . '</h2></div>';
					}

					if ( ! empty( $subheadline ) ) {
						$output .= '<p>' . wp_kses_post( $subheadline ) . '</p>';
					}
					$output .= '</div><!-- .featured-heading-wrap -->';
				}

				$output .= '
				<div class="featured-content-wrap">
					<section class="widget widget_' . esc_attr( implode( ' ', $classes ) ) . '">';

				// Select content
				if ( 'demo' === $content_select ) {
					$output .= decree_demo_content( $options );
				} elseif ( 'post' === $content_select || 'page' === $content_select || 'category' === $content_select ) {
					$output .= decree_page_post_category_content( $options );
				} elseif ( 'image' === $content_select ) {
					$output .= decree_image_content( $options );
				}

				$output .= '
								</section>
							</div><!-- .featured-content-wrap -->
						</div><!-- .wrapper -->
					</div><!-- #featured-content -->';
				set_transient( 'decree_featured_content', $output, 86940 );

			} // End if().

			echo $output;
		} // End if().
	}
endif;


if ( ! function_exists( 'decree_featured_content_display_position' ) ) :
	/**
	 * Homepage Featured Content Position
	 *
	 * @action decree_content, decree_after_secondary
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_featured_content_display_position() {
		// Getting data from Theme Options
		$options  = decree_get_theme_options();
		$position = $options['featured_content_position'];

		if ( $position ) {
			add_action( 'decree_after_content', 'decree_featured_content_display', 30 );
		} else {
			add_action( 'decree_before_content', 'decree_featured_content_display', 40 );
		}
	}
	endif; // decree_featured_content_display_position
add_action( 'decree_before', 'decree_featured_content_display_position' );


if ( ! function_exists( 'decree_demo_content' ) ) :
	/**
	 * This function to display featured posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_content( $options ) {
		// get data value from options
		$options 		= decree_get_theme_options();

		$output = '
			<article id="featured-post-1" class="post hentry post-demo">
				<figure class="featured-content-image">
					<img alt="Medical law" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/featured1-200x200.png" />
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="Medical law" href="#">Medical law</a>
						</h2>
					</header>
					<div class="entry-summary">
						<p>The main areas of focus for medical law include confidentiality, negligence and other torts related to medical treatment (especially medical malpractice), and criminal law and ethics. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</article>

			<article id="featured-post-2" class="post hentry post-demo">
				<figure class="featured-content-image">
					<img alt="Car Accident" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/featured2-200x200.png" />
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="Car Accident" href="#">Car Accident</a>
						</h2>
					</header>
					<div class="entry-summary">
						<p>Distracted driving, speeding, and drunk driving are all preventable behaviors- but they\'re also some of the most common causes of car accidents. Our lawyers are here for you. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</article>

			<article id="featured-post-3" class="post hentry post-demo">
				<figure class="featured-content-image">
					<img alt="Taxation Law" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/featured3-200x200.png" />
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="Taxation Law" href="#">Taxation Law</a>
						</h2>
					</header>
					<div class="entry-summary">
						<p> Taxation Law covers the rules, policies and laws that oversee the tax process, which involves charges on estates, transactions, property, income, licenses and more by the government. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</article>';

		if( 'four-columns' === $options['featured_content_layout'] || 'two-columns' === $options['featured_content_layout'] ) {
			$output .= '
			<article id="featured-post-4" class="post hentry post-demo">
				<figure class="featured-content-image">
					<img alt="Real Estate Law" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/featured4-200x200.png" />
				</figure>
				<div class="entry-container">
					<header class="entry-header">
						<h2 class="entry-title">
							<a title="Real Estate Law" href="#">Real Estate Law</a>
						</h2>
					</header>
					<div class="entry-summary">
						<p>Real Estate Law covers an extensive legal area, which is regulated by federal and state statutes, as well as common law. Many aspects of this area overlap with contract law. <span class="more-button"><a class="button-minimal" href="#">Read More ...</a></span></p>
					</div><!-- .entry-summary -->
				</div><!-- .entry-container -->
			</article>';
		}

		return $output;
	}
endif; // decree_demo_content


if ( ! function_exists( 'decree_page_post_category_content' ) ) :
	/**
	 * This function to display featured posts/post/category content
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_page_post_category_content( $options ) {
		$no_of_post   = 0; // for number of posts
		$post_list    = array();// list of valid post/page ids
		$quantity     = $options['featured_content_number'];
		$type         = $options['featured_content_type'];
		$show_content = $options['featured_content_show'];

		$output     = '<div class="featured_content_slider_wrap">';

		$args = array(
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if( 'post' === $type || 'page' === $type ) {
			if( 'page' === $type ) {
				$args['post_type'] = 'page';
			}

			for ( $i = 1; $i <= $quantity; $i++ ) {
				$post_id = '';

				if( 'post' === $type ) {
					$post_id = isset( $options['featured_content_post_' . $i] ) ? $options['featured_content_post_' . $i] : false;
				}
				elseif( 'page' === $type ) {
					$post_id = isset( $options['featured_content_page_' . $i] ) ? $options['featured_content_page_' . $i] : false;
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
			$args['order_by'] = 'post__in';
		}
		elseif( 'category' === $type ) {
			$no_of_post = $quantity;

			if ( ! empty( $options['featured_content_select_category'] ) ) {
				$args['category__in'] = $options['featured_content_select_category'];
			}
		}

		if ( 0 === $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;

		$loop = new WP_Query( $args );

		while ( $loop->have_posts()) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			$excerpt = get_the_excerpt();

			$output .= '
				<article id="featured-post-' . esc_attr( $loop->current_post ) . '" class="post hentry post">';

				//Default value if there is no first image
				$image = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-480x480.jpg" >';

				if ( has_post_thumbnail() ) {
					$image = get_the_post_thumbnail( get_the_ID(), 'post-thumbnail', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
				}
				else {
					//Get the first image in page, returns false if there is no image
					$first_image = decree_get_first_image( get_the_ID(), 'post-thumbnail', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );

					//Set value of image as first image if there is an image present in the page
					if ( $first_image ) {
						$image = $first_image;
					}
				}

				$output .= '
					<figure class="featured-homepage-image">
						<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">
						'. $image . '
						</a>
					</figure>';

				$output .= '
					<div class="entry-container">
						<header class="entry-header">
							<h2 class="entry-title">
								<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
							</h2>
						</header>';
						if ( 'excerpt' === $show_content ) {
							$output .= '<div class="entry-summary"><p>' . $excerpt . '</p></div><!-- .entry-summary -->';
						}
						elseif ( 'full-content' === $show_content ) {
							$content = apply_filters( 'the_content', get_the_content() );
							$content = str_replace( ']]>', ']]&gt;', $content );
							$output .= '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
						}
					$output .= '
					</div><!-- .entry-container -->
				</article><!-- .featured-post-' . esc_attr( $loop->current_post ) . ' -->';

		} // endwhile;

		wp_reset_postdata();

		return $output;
	}
endif; // decree_post_content


if ( ! function_exists( 'decree_image_content' ) ) :
	/**
	 * This function to display featured posts content
	 *
	 * @get the data value from theme options
	 * @displays on the index
	 *
	 * @useage Featured Image, Title and Excerpt of Post
	 *
	 * @uses set_transient
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_image_content( $options ) {
		$quantity     = $options['featured_content_number'];
		$show_content = $options['featured_content_show'];

		$output = '';

		for ( $i = 1; $i <= $quantity; $i++ ) {
			$target = '_self';

			if ( ! empty( $options[ 'featured_content_target_' . $i ] ) ) {
				$target = '_blank';
			}

			//Checking Link
			$link = '#';

			if ( ! empty( $options[ 'featured_content_link_' . $i ] ) ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL(  $options[ 'featured_content_link_' . $i ] );
				}
				else {
					$link = $options[ 'featured_content_link_' . $i ];
				}
			}

			//Checking Title
			$title = '';

			if ( ! empty( $options[ 'featured_content_title_'. $i ] ) ) {
				$title = $options[ 'featured_content_title_'. $i ];
			}

			//Checking Content
			$content = '';

			if ( ! empty( $options[ 'featured_content_content_'. $i ] ) ) {
				$content = $options[ 'featured_content_content_'. $i ];
			}

			//Checking BUtton Text
			$button_text = '';

			if ( ! empty( $options[ 'featured_content_button_text_'. $i ] ) ) {
				$button_text = $options[ 'featured_content_button_text_'. $i ];
			}

			$output .= '
			<article id="featured-post-' . esc_attr( $i ) . '" class="post hentry image">';
				if ( ! empty ( $options[ 'featured_content_image_' . $i ] ) ) {
					$output .= '
					<figure class="featured-homepage-image">
						<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . esc_attr( $target ) . '">
							<img src="' . esc_url( $options[ 'featured_content_image_' . $i ] ) . '" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
						</a>
					</figure>';
				}
				if ( '' !== $title  || $content!='' ) {
					$output .= '
					<div class="entry-container">';
						if ( '' !== $title  ) {
							$output .= '
							<header class="entry-header">
								<h2 class="entry-title">
									<a href="' . esc_url( $link ) . '" rel="bookmark" target="' . esc_attr( $target ) . '">' .$title . '</a>
								</h2>
							</header>';
						}
						if ( 'hide-content' !== $show_content ) {
							if ( '' !== $content )  {
								$output .= '
								<div class="entry-content"><p>
									' . $content . '
								</p></div>';
							}
						}
						if ( '' !== $button_text  ) {
							$output .= '<span class="more-button"><a class="button-minimal" href="' . esc_url( $link ) . '" target="' . esc_attr( $target ) . '">'. esc_html( $button_text ).'</a></span>';
						}
					$output .= '
					</div><!-- .entry-container -->';
				}
			$output .= '
			</article><!-- .featured-post-' . esc_attr( $i ) . ' -->';

		}
		return $output;
	}
endif; //decree_image_content
