<?php
/**
 * The template for displaying the Slider
 *
 * @package Decree Pro
 */



if ( ! function_exists( 'decree_logo_slider' ) ) :
	/**
	 * Add slider.
	 *
	 * @uses action hook decree_before_content.
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_logo_slider() {
		// decree_flush_transients();

		$output = '';

		// get data value from options
		$options       = decree_get_theme_options();
		$enable_slider = $options['logo_slider_option'];
		$layout        = $options['logo_slider_visible_items'];
		$slider_type   = $options['logo_slider_type'];

		if ( decree_check_section( $enable_slider ) ) {
			if ( ! $output = get_transient( 'decree_logo_slider' ) ) {
				echo '<!-- refreshing cache -->';

				if ( 1 === $layout ) {
					$class[] = 'one-column';
				} elseif ( 2 === $layout ) {
					$class[] = 'two-columns';
				} elseif ( 3 === $layout ) {
					$class[] = 'three-columns';
				} elseif ( 4 === $layout ) {
					$class[] = 'four-columns';
				} elseif ( 5 === $layout ) {
					$class[] = 'five-columns';
				}

				$class[] = $slider_type;

				$output = '
					<div id="logo-section" class="sections ' . esc_attr( implode( ' ', $class ) ) . '">
						<div class="wrapper">';
						if ( 'demo' === $slider_type ) {
							$output .= '
							<div class="section-heading-wrap">';

							$output .= '
								<div class="entry-header">
									<h2 class="section-title entry-title">Logo Slider</h2>
								</div><!-- .entry-header -->

								<p>This is Logo Slider.';

							if ( current_user_can( 'edit_theme_options' ) ) {
								$output .= ' You can edit this from Appearance - Customize - Theme Options - Logo Slider. Detailed information of Logo Slider can be found in our theme instructions page.';
							}

							$output .= '</p>
							</div><!-- .section-heading-wrap -->';
						} elseif ( '' !== $options['logo_slider_title'] || '' !== $options['logo_slider_description'] ) {
							$output .= '<div class="section-heading-wrap">';

							if ( '' !== $options['logo_slider_title'] ) {
								$output .= '<div class="entry-header"><h2 class="section-title entry-title">' . $options['logo_slider_title'] . '</h2></div><!-- .entry-header -->';
							}

							if ( '' !== $options['logo_slider_description'] ) {
								$output .= '<p>' . $options['logo_slider_description'] . '</p>';
							}

							$output .= '</div><!-- .section-heading-wrap -->';
						}

						$output .= '
							<div class="logo_slider_content_slider_wrap cycle-slideshow section-content-wrap"
								data-cycle-log="false"
								data-cycle-pause-on-hover="true"
								data-cycle-swipe="true"
								data-cycle-fx=carousel
								data-cycle-carousel-fluid=true
								data-cycle-carousel-visible="'. absint( $options['logo_slider_visible_items'] ) . '"

								data-cycle-speed="'. esc_attr( $options['logo_slider_transition_length'] ) * 1000 . '"
								data-cycle-timeout="'. esc_attr( $options['logo_slider_transition_delay'] ) * 1000 . '"
								data-cycle-slides="> article"
								>';

								if ( 'demo' === $slider_type ) {
									$output .= decree_demo_logo_slider();
								}
								elseif ( 'post' === $slider_type || 'page' === $slider_type || 'category' === $slider_type) {
									$output .= decree_post_page_category_logo_slider( $options );
								}
								else {
									$output .= decree_image_logo_slider( $options );
								}

				$output .= '
							</div><!-- .logo_slider_content_slider_wrap.cycle-slideshow -->
						</div><!-- .wrapper -->
					</div><!-- #slider-section -->';
			}

			set_transient( 'decree_logo_slider', $output, 86940 );
		}

		echo $output;
	}
endif;
add_action( 'decree_before_content', 'decree_logo_slider', 80 );


if ( ! function_exists( 'decree_demo_logo_slider' ) ) :
/**
 * This function to display featured posts content
 *
 * @get the data value from customizer options
 *
 * @since Decree Pro 1.0
 *
 */
function decree_demo_logo_slider() {
	return '
	<article id="featured-logo-1" class="post hentry post-demo">
		<figure class="featured-content-image">
			<a href="#" rel="bookmark">
				<img alt="Demo Logo One" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/logo1.png" />
			</a>
		</figure>
	</article>

	<article id="featured-logo-2" class="post hentry post-demo">
		<figure class="featured-content-image">
			<a href="#" rel="bookmark">
				<img alt="Demo Logo Two" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/logo2.png" />
			</a>
		</figure>
	</article>

	<article id="featured-logo-3" class="post hentry post-demo">
		<figure class="featured-content-image">
			<a href="#" rel="bookmark">
				<img alt="Demo Logo Three" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/logo3.png" />
			</a>
		</figure>
	</article>

	<article id="featured-logo-4" class="post hentry post-demo">
		<figure class="featured-content-image">
			<a href="#" rel="bookmark">
				<img alt="Demo Logo Four" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/logo4.png" />
			</a>
		</figure>
	</article>

	<article id="featured-logo-5" class="post hentry post-demo">
		<figure class="featured-content-image">
			<a href="#" rel="bookmark">
				<img alt="Demo Logo Five" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/logo5.png" />
			</a>
		</figure>
	</article>';
}
endif; // decree_demo_logo_slider


if ( ! function_exists( 'decree_post_page_category_logo_slider' ) ) :
/**
 * This function to display hero posts content
 *
 * @param $options: decree_theme_options from customizer
 *
 * @since Decree Pro 1.0
 */
function decree_post_page_category_logo_slider( $options ) {
	$quantity   = $options['logo_slider_number'];
	$no_of_post = 0; // for number of posts
	$post_list  = array();// list of valid post/page ids
	$type       = $options['logo_slider_type'];
	$output     = '';

	$args = array(
		'ignore_sticky_posts' => 1 // ignore sticky posts
	);

	//Get valid number of posts
	if ( 'post' === $type || 'page' === $type ) {
		if( 'page' === $type ) {
			$args['post_type'] = 'page';
		}

		for ( $i = 1; $i <= $quantity; $i++ ) {
			$post_id = '';

			if ( 'post' === $type ) {
				$post_id = isset( $options[ 'logo_slider_post_' . $i ] ) ? $options[ 'logo_slider_post_' . $i ] : false;
			}
			elseif ( 'page' === $type ) {
				$post_id = isset( $options[ 'logo_slider_page_' . $i ] ) ? $options[ 'logo_slider_page_' . $i ] : false;
			}

			if ( $post_id && '' !== $post_id ) {
				// Polylang Support.
				if ( class_exists( 'Polylang' ) ) {
					$post_id = pll_get_post( $post_id, pll_current_language() );
				}

				$post_list = array_merge( $post_list, array( $post_id ) );

				$no_of_post++;
			}
		}

		$args['post__in'] = $post_list;
		$args['order_by'] = 'post__in';
	}
	elseif ( 'category' === $type ) {
		$no_of_post           = $quantity;

		if ( ! empty( $options['logo_slider_select_category'] ) ) {
			$args['category__in'] = $options['logo_slider_select_category'];
		}

		$args['post_type'] = 'post';
	}

	if ( 0 === $no_of_post ) {
		return;
	}

	$args['posts_per_page'] = $no_of_post;
	$get_hero_posts         = new WP_Query( $args );

	$i = 0;
	while ( $get_hero_posts->have_posts() ) {
		$get_hero_posts->the_post();

		$i++;

		$title_attribute = the_title_attribute( 'echo=0' );

		$output .= '
			<article id="post-' . $i . '" class="post-' . $i . ' hentry">';

			//Default value if there is no first image
			$image = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-480x480.jpg" >';

			if ( has_post_thumbnail() ) {
				$image = get_the_post_thumbnail( get_the_ID(), 'full', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
			} else {
				//Get the first image in page, returns false if there is no image
				$first_image = decree_get_first_image( get_the_ID(), 'full', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
				//Set value of image as first image if there is an image present in the page
				if ( $first_image ) {
					$image = $first_image;
				}
			}

			$output .= '
				<figure class="featured-content-image">
					<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">
					'. $image . '
					</a>
				</figure>';

			$output .= '
			</article><!-- .post-' . $i . ' -->';
		} //endwhile

	wp_reset_postdata();

	return $output;
}
endif; // decree_post_page_category_logo_slider


function decree_image_logo_slider( $options ) {
	$quantity = $options['logo_slider_number'];

	$output = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {

		//Check Image Not Empty to add in the slides
		if ( ! empty( $options[ 'logo_slider_image_'. $i ] ) ) {

			$title = '';

			if ( ! empty( $options[ 'logo_slider_title_'. $i ] ) ) {
				$title = $options[ 'logo_slider_title_'. $i ];
			}

			$image  = '<img alt="'. esc_attr( $title ) . '" class="wp-post-image" src="'. esc_url( $options['logo_slider_image_'. $i] ).'" />';

				//Checking Link
			if ( ! empty( $options[ 'logo_slider_link_'. $i ] ) ) {
				$link = $options[ 'logo_slider_link_'. $i ];

				//Checking Link Target
				if ( ! empty( $options[ 'logo_slider_target_'. $i ] ) ) {
					$target = '_blank';
				} else {
					$target = '_self';
				}

				//Checking image
				$image = '<a href="'. esc_url( $link ).'" title="'. esc_attr( $title ) . '" target="' . $target . '">'. $image . '</a>';

			}

			$output .= '
				<article id="featured-post-'. esc_attr( $i ) . '" class="post hentry displaynone">
					<figure class="featured-content-image">
						'. $image . '
					</figure>
				</article><!-- .slides --> ';
		}
	}
	return $output;
}
