<?php
/**
 * The template for displaying Testimonial
 *
 * @package Decree Pro
 */



if ( ! function_exists( 'decree_testimonial_display' ) ) :
	/**
	* Add Featured content.
	*
	* @uses action hook decree_before_content.
	*
	* @since Decree Pro 1.0
	*/
	function decree_testimonial_display() {
		//decree_flush_transients();

		$output = '';

		// get data value from options
		$options        = decree_get_theme_options();
		$enable_content = $options['testimonial_option'];
		$content_select = $options['testimonial_type'];
		$slider_select  = $options['testimonial_slider'];

		if ( decree_check_section( $enable_content ) ) {
			if ( !$output = get_transient( 'decree_testimonial' ) ) {
				echo '<!-- refreshing cache -->';

				$layouts 	 = $options['testimonial_layout'];
				$headline 	 = $options['testimonial_headline'];
				$subheadline = $options['testimonial_subheadline'];

				if ( ! empty( $layouts ) ) {
					$classes = $layouts ;
				}

				$classes .= ' ' . $content_select ;

				if ( 'demo' === $content_select ) {
					$headline    = esc_html__( 'Testimonials', 'decree-pro' );
					$subheadline = esc_html__( 'Here you can showcase the x number of Testimonials.', 'decree-pro' );
				}

				if ( $options['testimonial_position'] ) {
					$classes .= ' border-top' ;
				}

				$output = '
					<div id="testimonial-section" class="sections ' . $classes . '">
						<div class="wrapper">';
							if ( ! empty( $headline ) || ! empty( $subheadline ) ) {
								$output .= '<div class="section-heading-wrap">';

								if ( ! empty( $headline ) ) {
									$output .= '<div class="entry-header"><h2 class="section-title entry-title">' . wp_kses_post( $headline ) . '</h2></div>';
								}

								if ( ! empty( $subheadline ) ) {
									$output .= '<p>' . wp_kses_post( $subheadline ) . '</p>';
								}

								$output .= '
								</div><!-- .featured-heading-wrap -->';
							}
							$output .= '
							<div class="section-content-wrap">';

								if ( $slider_select ) {
									$output .= '
									<div class="cycle-slideshow"
									    data-cycle-log="false"
									    data-cycle-pause-on-hover="true"
									    data-cycle-swipe="true"
									    data-cycle-auto-height=container
										data-cycle-slides=".testimonial_slider_wrap"
										data-cycle-fx="fade"
										>

										<!-- prev/next links -->
							    		<div class="cycle-prev"></div>
							    		<div class="cycle-next"></div>';
								}

								// Select content
								if ( 'demo' === $content_select ) {
									$output .= decree_demo_testimonial( $options );
								}
								elseif ( 'post' === $content_select || 'jetpack-testimonial' === $content_select || 'page' === $content_select || 'category' === $content_select ) {
									$output .= decree_post_page_category_testimonial( $options );
								}
								elseif ( 'image' === $content_select ) {
									$output .= decree_image_testimonial( $options );
								}

								if ( $slider_select ) {
									$output .= '
									</div><!-- .cycle-slideshow -->';
								}

				$output .= '
							</div><!-- .section-content-wrap -->
						</div><!-- .wrapper -->
					</div><!-- #testimonial-section -->';

			}

			set_transient( 'decree_testimonial', $output, 86940 );
		}
		echo $output;
	}
endif;


if ( ! function_exists( 'decree_testimonial_display_position' ) ) :
	/**
	 * Homepage Testimonial Position
	 *
	 * @action decree_content, decree_after_secondary
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_testimonial_display_position() {
		// Getting data from Theme Options
		$options = decree_get_theme_options();

		if ( $options['testimonial_position'] ) {
			add_action( 'decree_after_content', 'decree_testimonial_display', 40 );
		}
		else {
			add_action( 'decree_before_content', 'decree_testimonial_display', 70 );
		}
	}
endif; // decree_testimonial_display_position
add_action( 'decree_before', 'decree_testimonial_display_position' );


if ( ! function_exists( 'decree_demo_testimonial' ) ) :
	/**
	 * This function to display featured posts content
	 *
	 * @get the data value from customizer options
	 *
	 * @since Decree Pro 1.0
	 *
	 */
	function decree_demo_testimonial( $options ) {
		$output = '';

		if ( $options['testimonial_slider'] ) {
			$output = '<div class="testimonial_slider_wrap">';
		}

		$output .= '
			<article id="testimonial-post-1" class="post hentry post-demo">
				<div class="entry-container">
					<div class="entry-container-wrap">
						<div class="entry-content"><p>I would describe the university as exciting and dynamic. The best thing about being a student here is the number of additional opportunities that are available. I was initially attracted here by my supervisor, the school\'s reputation, and my career goals.</p>
						</div>
						<header class="entry-header">
							<h2 class="entry-title"><a href="#">Benjamin Balazs</a></h2>
							<p class="entry-meta"><span class="position">CEO, XYZ Limited</span></p>
						</header>
					</div><!-- .entry-container-wrap -->
				</div><!-- .entry-container -->
				<figure class="featured-image">
					<a href="#" title="Benjamin Balazs">
						<img alt="Benjamin Balazs" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/testimonial1-320x320.jpg" />
					</a>
				</figure>
			</article>';

			if ( 'two-columns' === $options['testimonial_layout'] || 'four-columns' === $options['testimonial_layout'] ) {
				$output .= '
				<article id="testimonial-post-2" class="post hentry post-demo">
					<div class="entry-container">
						<div class="entry-container-wrap">
							<div class="entry-content"><p>The University offers a fantastic academic environment, seminars, interdisciplinary initiatives, as well as a remarkable library and sport facility. For these reasons, I would heartily recommend the university to other students.</p>
							</div>
							<header class="entry-header">
								<h2 class="entry-title"><a href="#">Dzee Shah</a></h2>
								<p class="entry-meta"><span class="position">CTO, ABC Limited</span></p>
							</header>
						</div><!-- .entry-container-wrap -->
					</div><!-- .entry-container -->
					<figure class="featured-image">
						<a href="#" title="Dzee Shah">
							<img alt="Dzee Shah" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/testimonial2-320x320.jpg" />
						</a>
					</figure>
				</article>';
			}

		if ( $options['testimonial_slider'] ) {
			$output .= '
			</div><!-- .testimonial_slider_wrap -->

			<div class="testimonial_slider_wrap">';
		}

		$output .= '
			<article id="testimonial-post-3" class="post hentry post-demo">
				<div class="entry-container">
					<div class="entry-container-wrap">
						<div class="entry-content"><p>I can positively say the university has made me a better person. It has helped me develop a positive attitude towards my studies and discover more about myself. Teachers are very caring and interested in students\' well-being. They make sure every class is fun and interactive.</p></div>
						<header class="entry-header">
							<h2 class="entry-title"><a href="#">Song Jay</a></h2>
							<p class="entry-meta"><span class="position">CFO, TAC Limited</span></p>
						</header>
					</div><!-- .entry-container-wrap -->
				</div><!-- .entry-container -->
				<figure class="featured-image">
					<a href="#" title="Song Jay">
						<img alt="Song Jay" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/testimonial3-320x320.jpg" />
					</a>
				</figure>
			</article>';

			if ( 'two-columns' === $options['testimonial_layout'] || 'four-columns' === $options['testimonial_layout'] ) {
				$output .= '
				<article id="testimonial-post-4" class="post hentry post-demo">
					<div class="entry-container">
						<div class="entry-container-wrap">
							<div class="entry-content"><p>I like the friendly atmosphere here and the fact the teachers are really close to the students. We are very supported in our studies. Some of the teachers are really kind and their way of teaching is really interesting. They are also very motivational. We are enthused by the classes.</p></div>
							<header class="entry-header">
								<h2 class="entry-title"><a href="#">Sophia Johns</a></h2>
								<p class="entry-meta"><span class="position">FCA, TYQ Limited</span></p>
							</header>
						</div><!-- .entry-container-wrap -->
					</div><!-- .entry-container -->
					<figure class="featured-image">
						<a href="#" title="Sophia Johns">
							<img alt="Sophia Johns" class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/testimonial4-320x320.jpg" />
						</a>
					</figure>
				</article>';
			};

		if ( $options['testimonial_slider'] ) {
			$output .= '
			</div><!-- .testimonial_slider_wrap -->';
		}

		return $output;
	}
endif; // decree_demo_testimonial


if ( ! function_exists( 'decree_post_page_category_testimonial' ) ) :
	/**
	 * This function to display featured posts content
	 *
	 * @param $options: decree_theme_options from customizer
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_post_page_category_testimonial( $options ) {
		global $post;

		$quantity   = $options['testimonial_number'];
		$no_of_post = 0; // for number of posts
		$post_list  = array();// list of valid post/page ids
		$type       = $options['testimonial_type'];
		$layouts    = 1;
		$output     = '';

		if ( 'two-columns' === $options['testimonial_layout'] ) {
			$layouts = 2;
		}

		$args = array(
			'ignore_sticky_posts' => 1 // ignore sticky posts
		);

		//Get valid number of posts
		if ( 'post' === $type || 'jetpack-testimonial' === $type || 'page' === $type  ) {
			$args['post_type'] = $type;

			for ( $i = 1; $i <= $quantity; $i++ ) {
				$post_id = '';

				if ( 'post' === $type ) {
					$post_id = isset( $options['testimonial_post_' . $i] ) ? $options['testimonial_post_' . $i] : false;
				} elseif ( 'page' === $type ) {
					$post_id = isset( $options['testimonial_page_' . $i] ) ? $options['testimonial_page_' . $i] : false;
				} elseif ( 'jetpack-testimonial' === $type ) {
					$post_id = isset( $options['testimonial_cpt_' . $i] ) ? $options['testimonial_cpt_' . $i] : false;
				}

				if ( $post_id && '' !== $post_id ) {
					// Polylang Support.
					if ( class_exists( 'Polylang' ) ) {
						$post_id = pll_get_post( $post_id, pll_current_language() );
					}

					$post_list = array_merge( $post_list, array( $post_id ) );

					$no_of_post++;
				}
			}

			$args['post__in'] = $post_list;
			$args['order_by'] = 'post__in';
		}
		elseif ( 'category' === $type ) {
			$no_of_post = $quantity;

			if ( ! empty( $options['testimonial_select_category'] ) ) {
				$args['category__in'] = $options['testimonial_select_category'];
			}

			$args['post_type'] = 'post';
		}

		if ( 0 === $no_of_post ) {
			return;
		}

		$args['posts_per_page'] = $no_of_post;
		$loop     = new WP_Query( $args );

		if ( $options['testimonial_slider'] ) {
			$output = '<div class="testimonial_slider_wrap">';
		}

		while ( $loop->have_posts() ) {
			$loop->the_post();

			$title_attribute = the_title_attribute( 'echo=0' );

			$i = absint( $loop->current_post + 1 );

			$output .= '
				<article id="testimonial-post-' . $i . '" class="status-publish has-post-thumbnail hentry ' . esc_attr( $type ) . '">';

				//Default value if there is no first image
				$image = '<img class="wp-post-image" src="' . trailingslashit( esc_url ( get_template_directory_uri() ) ) . 'images/no-featured-image-80x80.jpg" >';

				if ( has_post_thumbnail() ) {
					$image = get_the_post_thumbnail( $post->ID, 'decree-small', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
				}
				else {
					// Get the first image in page, returns false if there is no image.
					$first_image = decree_get_first_image( $post->ID, 'decree-small', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );

					// Set value of image as first image if there is an image present in the page.
					if ( $first_image ) {
						$image = $first_image;
					}
				}

				$output .= '
					<div class="entry-container">
						<div class="entry-container-wrap">';

				if ( 'excerpt' === $options['testimonial_show'] ) {
					//Show Excerpt
					$output .= '
						<div class="entry-summary"><p>' . get_the_excerpt() . '</p></div><!-- .entry-summary -->';
				}
				elseif ( 'full-content' === $options['testimonial_show'] ) {
					//Show Content
					$content = apply_filters( 'the_content', get_the_content() );
					$content = str_replace( ']]>', ']]&gt;', $content );
					$output .= '<div class="entry-content">' . wp_kses_post( $content ) . '</div><!-- .entry-content -->';
				}

				if ( $options['testimonial_enable_title'] ) {
					$output .= the_title( '<header class="entry-header"><h2 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h2></header><!-- .entry-header -->', false );
				}

				$output .= '
						</div><!-- .entry-container-wrap -->
					</div><!-- .entry-container -->
					<figure class="featured-image">
						<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">
						'. $image . '
						</a>
					</figure>
				</article><!-- .featured-post-' . $i . ' -->';

				if ( 0 === ( $i % $layouts ) && $i < $no_of_post ) {
					//end and start testimonial_slider_wrap div based on logic
					if ( $options['testimonial_slider'] ) {
						$output .= '
						</div><!-- .testimonial_slider_wrap -->

						<div class="testimonial_slider_wrap">';
					}
				}
			} //endwhile

		wp_reset_postdata();

		if ( $options['testimonial_slider'] ) {
			$output .= '
			</div><!-- .testimonial_slider_wrap -->';
		}

		return $output;
	}
endif; // decree_post_page_category_testimonial


if ( ! function_exists( 'decree_image_testimonial' ) ) :
	/**
	 * This function to display featured posts content
	 *
	 * @get the data value from theme options
	 * @displays on the index
	 *
	 * @useage Featured Image, Title and Excerpt of Post
	 *
	 * @uses set_transient
	 *
	 * @since Decree Pro 1.0
	 */
	function decree_image_testimonial( $options ) {
		$quantity = $options['testimonial_number'];
		$layouts  = 1;
		$output   = '';

		if ( 'two-columns' === $options['testimonial_layout'] ) {
			$layouts = 2;
		}

		if ( $options['testimonial_slider'] ) {
			$output = '<div class="testimonial_slider_wrap">';
		}

		for ( $i = 1; $i <= $quantity; $i++ ) {
			$content = '';
			$target  = '_self';
			$link    = '#';
			$title   = '';
			$image   = '';

			if ( ! empty( $options[ 'testimonial_target_' . $i ] ) ) {
				$target = '_blank';
			}

			// Checking Link.
			if ( ! empty( $options[ 'testimonial_link_' . $i ] ) ) {
				// support qTranslate plugin.
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$link = qtrans_convertURL(  $options[ 'testimonial_link_' . $i ] );
				} else {
					$link = $options[ 'testimonial_link_' . $i ];
				}
			}

			// Checking Title.
			if ( ! empty( $options[ 'testimonial_title_'. $i ] ) || ! empty( $options[ 'testimonial_position_'. $i ] ) ) {
				$title = '
				<header class="entry-header">';

				if ( ! empty( $options[ 'testimonial_title_'. $i ] ) ) {
					$title .= '
					<h2 class="entry-title">
						<a title="' . esc_attr( $options[ 'testimonial_title_'. $i ] ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">' . esc_html( $options[ 'testimonial_title_'. $i ] ) . '</a>
					</h2>';
				}

				if ( ! empty( $options[ 'testimonial_position_'. $i ] ) ) {
					$title .= '<p class="entry-meta"><span class="position">' . esc_html( $options[ 'testimonial_position_'. $i ] ) . '</span></p>';
				}

				$title .= '</header>';
			}

			// Checking Content.
			if ( ! empty( $options[ 'testimonial_content_'. $i ] ) ) {
				$content = '<div class="entry-content">' . $options[ 'testimonial_content_'. $i ] . '</div>';
			}

			if ( ! empty( $options[ 'testimonial_image_' . $i ] ) ) {
				$image .= '
				<figure class="featured-image">
					<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . $target . '">
						<img src="' . esc_url( $options[ 'testimonial_image_' . $i ] ) . '" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
					</a>
				</figure>';
			}

			$output .= '
			<article id="testimonial-post-' . esc_attr( $i ) . '" class="post hentry post-demo">
				<div class="entry-container">
					<div class="entry-container-wrap">
						' . $content . $title . '
					</div><!-- .entry-container-wrap -->
				</div><!-- .entry-container -->
				' . $image . '
			</article>';

			if ( 0 === ( $i % $layouts ) && $i < $quantity ) {
				// end and start testimonial_slider_wrap div based on logic.
				if ( $options['testimonial_slider'] ) {
					$output .= '
					</div><!-- .testimonial_slider_wrap -->

					<div class="testimonial_slider_wrap">';
				}
			}
		} // End for().

		if ( $options['testimonial_slider'] ) {
			$output .= '
			</div><!-- .testimonial_slider_wrap -->';
		}

		return $output;
	}
endif; // decree_image_testimonial.
